% Computes and plots zonal standard deviation for CMIP5 and CMIP6 models
% Supplementary Figure 4 panel b
% M.Freund (freundm@unimelb.edu.au)
% 27.02.2020
% All models available on NCI
% getCMIP6runsENSO& getCMIP5runsENSO accquires: listing = dir([main_path,exp_path,'*.nc']);



%% Additional matlab libs required:
%  cbrewinterp & cbrewer & panel
%  read netcdf lib matlab (get_climdata)
%  additional functions below



%% Get listing of NCI CMIP5 and CMIP6 data
%%----%%
selection.exp_list={'hist','ssp585'};
selection.stage='update2';

% Get all available CMIP5 and CMIP6 runs
All_CMIP6_runs = getCMIP6runsENSO(selection);
All_CMIP5_runs = getCMIP5runsENSO;

% Put CMIP5 and CMIP6 together
All_Runs_Pacific=[All_CMIP5_runs,All_CMIP6_runs];

% Number of models
NboM=numel(All_Runs_Pacific);

%% Get the observations
[~,hadsttobj]=get_climdata('../~/Climate_data/Clim_data/HadISST2016/HadISST_sst.nc');
% Select region
hadsttobj=hadsttobj.Region([138,-68,2,-2]);
% Select Period
hadsttobj=hadsttobj.Period(datenum(1870:2014,1,1));
% Get standard deviation
hadsttobj_std=hadsttobj.Operation(@std);
% Get average
hadsttobj_std_yr=hadsttobj_std.ZonalOperation(@mean);


%% Read in all model files
for i_runs=1:NboM
    % Read in all paths
    [~,Runs_Pacific(i_runs).obj]=get_climdata(All_Runs_Pacific(i_runs).path);
end

%% Calculate zonal standard deviations
for i_runs=1:NboM
    inmodel=Runs_Pacific(i_runs).obj;
    % Select ony this region
    inmodelsel=inmodel.Region([139,-80,20,-20]);
    
    % Get Standard deviations
    inmodel_std_yr=inmodelsel.Operation(@std);
    
    % Build Zonal mean
    inmodel_std_yr_zn=inmodel_std_yr.Region([139,-80,2,-2]);
    inmodel_Pacific=inmodel_std_yr_zn.ZonalOperation(@mean);
    
    All_Runs_Pacific(i_runs). Zonal_means_CMIP=inmodel_Pacific;
    
    % Find peaks
    pos_Peaks=findpeaks(inmodel_Pacific.Data,1:inmodel_Pacific.NLon,'MinPeakHeight',inmodel_Pacific.Maximum/100*50,'MinPeakWidth',10);
    if length(pos_Peaks)==1
        All_Runs_Pacific(i_runs). Nb_of_Peaks=true;
    else
        All_Runs_Pacific(i_runs). Nb_of_Peaks=false;
    end
    
    [posymax,posxmax]=max(inmodel_Pacific.Data);
    posxmax_rel_lons=wrapTo360(inmodel_Pacific.Longitude(posxmax));
    All_Runs_Pacific(i_runs).posxmax_rel_lons=posxmax_rel_lons;
    All_Runs_Pacific(i_runs).posymax=posymax;
end



%% Plotting party
%-----------------------------------------------------------------------------


%% Give the models some colors!
% First CMIP5
linecolors = cbrewinterp(cbrewer('qual','Set3',12),length(All_Runs_6_Hist));
for iruns=1:length(All_Runs_6_Hist)
    All_Runs_6_Hist(iruns).Color=linecolors(iruns,:);
end

% Now CMIP5 accordingly
for i=1:length(All_Runs_5_Hist)
    All_Runs_5_Hist(i).Main_name=All_Runs_5_Hist(i).Full_name(1);
end


for i=1:size(All_Runs_6_Hist,2)
    StartingletterModel6=All_Runs_6_Hist(i).Full_name(1);
    index=strcmp({All_Runs_5_Hist.Main_name},StartingletterModel6);
    if sum(index)==0
    else
        position_index=find(index==true);
        for ps=1:length(position_index)
            All_Runs_5_Hist(position_index(ps)).Color=All_Runs_6_Hist(i).Color;
        end
    end
end


%% Figure zonal overview
color_cmip6=rgb('firebrick');
color_cmip5=rgb('darkslateblue');
color_models=rgb('dimgrey');

Fig=figure('visible','on');
Ax_zavg_obs=axes('parent',Fig);
set(zavg_obs,axes('parent',Fig);
set(gcf, 'Color', 'White');
set(gcf,'position',[   -1167         400         684         466]);

hold all

%------------ Plot the lines for the CMIP6 models
for i=1:numel(All_Runs_6_Hist)
    plot(wrapTo360(All_Runs_6_Hist(i). Zonal_means_CMIP.Longitude),All_Runs_6_Hist(i). Zonal_means_CMIP.Data,'color',color_models,'Linewidth',0.1,'Linestyle',':');
end
%------------ Plot the lines for the CMIP5 models
for i=1:numel(All_Runs_5_Hist)
    plot(wrapTo360(All_Runs_5_Hist(i). Zonal_means_CMIP.Longitude),All_Runs_5_Hist(i). Zonal_means_CMIP.Data,'color',color_models,'Linewidth',0.1,'Linestyle',':');
end


i=1;
% Interqautile range
h_cmip5_interquartile=plot_ts_patch((wrapTo360(All_Runs_5_Hist(i). Zonal_means_CMIP.Longitude)),prctile(data_5,25),prctile(data_5,75),color_cmip5);
h_cmip6_interquartile=plot_ts_patch((wrapTo360(All_Runs_6_Hist(i). Zonal_means_CMIP.Longitude)),prctile(data_6,25),prctile(data_6,75),color_cmip6);

h_cmip5_interquartile.FaceAlpha=0.45;
h_cmip6_interquartile.FaceAlpha=0.45;



%------------- Plot the naming CMIP5 models
for i=1:numel(All_Runs_5_Hist)
    plot(All_Runs_5_Hist(i).posxmax_rel_lons,All_Runs_5_Hist(i).posymax,'o','MarkerEdgeColor',All_Runs_5_Hist(i).Color,'MarkerFaceColor',All_Runs_5_Hist(i).Color,'MarkerSize',18)
    text(All_Runs_5_Hist(i).posxmax_rel_lons,All_Runs_5_Hist(i).posymax,All_Runs_5_Hist(i).Full_name,'Color',rgb('black'),'HorizontalAlignment','center','FontSize',11);
end


%------------- Plot the naming CMIP6 models
for i=1:numel(All_Runs_6_Hist)
    plot(All_Runs_6_Hist(i).posxmax_rel_lons,All_Runs_6_Hist(i).posymax,'o','MarkerEdgeColor',All_Runs_6_Hist(i).Color,'MarkerFaceColor',All_Runs_6_Hist(i).Color,'MarkerSize',18)
    text(All_Runs_6_Hist(i).posxmax_rel_lons,All_Runs_6_Hist(i).posymax,All_Runs_6_Hist(i).Full_name,'Color',rgb('black'),'HorizontalAlignment','center','FontSize',11,'FontWeight','bold');
end

% Median models
h_cmip5_median=plot(wrapTo360(All_Runs_6_Hist(i). Zonal_means_CMIP.Longitude),prctile(data_5,50),'color',color_cmip5,'Linewidth',2,'Linestyle','-.');
h_cmip6_median=plot(wrapTo360(All_Runs_6_Hist(i). Zonal_means_CMIP.Longitude),prctile(data_6,50),'color',color_cmip6,'Linewidth',2,'Linestyle','-.');
% Observations
h_hadISST=plot(wrapTo360(hadsttobj_std_yr.Longitude),hadsttobj_std_yr.Data,'color','k','Linewidth',2);
%h_ERSST=plot(wrapTo360(ersstobj_std_yr.Longitude),ersstobj_std_yr.Data,'color','k');

legend([h_cmip5_interquartile,h_cmip6_interquartile],{'CMIP5','CMIP6'},'Location','Northwest','Box','off');

Lon_names=LookupTable_Longitudenames(round(All_Runs_Pacific(i). Zonal_means_CMIP.Longitude(1:20:end)));
ax=gca;
ax.XLim=[wrapTo360(All_Runs_Pacific(i). Zonal_means_CMIP.Longitude(1)),wrapTo360(All_Runs_Pacific(i). Zonal_means_CMIP.Longitude(end))];
ax.FontSize=15;
ax.YLim=[0.3 2.65];
ax.XTick=[wrapTo360(All_Runs_Pacific(i). Zonal_means_CMIP.Longitude(1:20:end))];
ax.XTickLabel=Lon_names;
ylabel('Standard deviation (C)');
xlabel('Longitude');
title('Standard deviation of average SSTA (2S-2N)')

%% Plotting legend    CMIP5
% Legend-----------------------------
all_Linewidth=1;

Fig=figure('visible','on');
set(gcf, 'Color', 'White');
set(gcf,'position',[   -759   407   253   407]);
Ax_legend_CMIP5=axes('parent',Fig);
hold all
% Plot the lines for legend
for i=1:numel(All_Runs_5_Hist)
    if rem(i,2)
        % UnGerade
        plot([1 1.3],[i i],'color',All_Runs_5_Hist(i).Color,'Linewidth',all_Linewidth)
        plot(1,i,'o','MarkerEdgeColor',All_Runs_5_Hist(i).Color,'MarkerFaceColor',All_Runs_5_Hist(i).Color,'MarkerSize',17)
        if length(All_Runs_5_Hist(i).Full_name)==1
            if i>41
                text(1,i,All_Runs_5_Hist(i).Full_name,'Color',rgb('black'),'HorizontalAlignment','center','Fontsize',12,'FontWeight','bold');
            else
                text(1,i,All_Runs_5_Hist(i).Full_name,'Color',rgb('black'),'HorizontalAlignment','center','Fontsize',12);
            end
        else
            if i>41
                text(1,i,All_Runs_5_Hist(i).Full_name,'Color',rgb('black'),'HorizontalAlignment','center','Fontsize',12,'FontWeight','bold');
            else
                text(1,i,All_Runs_5_Hist(i).Full_name,'Color',rgb('black'),'HorizontalAlignment','center','Fontsize',12);
            end
        end
        text(1.3,i,All_Runs_5_Hist(i).model,'Color','k','Fontsize',11);
    else
        % Gerade
        plot([1.1 1.7],[i i],'color',All_Runs_5_Hist(i).Color,'Linewidth',all_Linewidth)
        plot(1.1,i,'o','MarkerEdgeColor',All_Runs_5_Hist(i).Color,'MarkerFaceColor',All_Runs_5_Hist(i).Color,'MarkerSize',17)
        if length(All_Runs_5_Hist(i).Full_name)==1
            if i>41
                text(1.1,i,All_Runs_5_Hist(i).Full_name,'Color',rgb('black'),'HorizontalAlignment','center','Fontsize',12,'FontWeight','bold');
            else
                text(1.1,i,All_Runs_5_Hist(i).Full_name,'Color',rgb('black'),'HorizontalAlignment','center','Fontsize',12);
            end
        else
            if i>41
                text(1.1,i,All_Runs_5_Hist(i).Full_name,'Color',rgb('black'),'HorizontalAlignment','center','Fontsize',12,'FontWeight','bold');
            else
                text(1.1,i,All_Runs_5_Hist(i).Full_name,'Color',rgb('black'),'HorizontalAlignment','center','Fontsize',12);
            end
        end
        text(1.7,i,All_Runs_5_Hist(i).model,'Color','k','Fontsize',11);
    end
end
% Plot Reference
text(1.1,numel(All_Runs_5_Hist)+2,'CMIP5 models','Color','k','Fontsize',16);


ax=gca;
ax.XLim=[1 2.7];
ax.YLim=[1 numel(All_Runs_5_Hist)+1];
ax.Visible='off';


%% Plotting legend  CMIP6
% Legend-----------------------------
all_Linewidth=1;

Fig=figure('visible','on');
set(gcf, 'Color', 'White');
set(gcf,'position',[   355   430   253   407]);
Ax_legend_CMIP6=axes('parent',Fig);
hold all
% Plot the lines for legend
for i=1:numel(All_Runs_6_Hist)
    if rem(i,2)
        % UnGerade
        plot([1 1.3],[i i],'color',All_Runs_6_Hist(i).Color,'Linewidth',all_Linewidth)
        plot(1,i,'o','MarkerEdgeColor',All_Runs_6_Hist(i).Color,'MarkerFaceColor',All_Runs_6_Hist(i).Color,'MarkerSize',17)
        if length(All_Runs_6_Hist(i).Full_name)==1
            if i>41
                text(1,i,All_Runs_6_Hist(i).Full_name,'Color',rgb('black'),'HorizontalAlignment','center','Fontsize',12,'FontWeight','bold');
            else
                text(1,i,All_Runs_6_Hist(i).Full_name,'Color',rgb('black'),'HorizontalAlignment','center','Fontsize',12,'FontWeight','bold');
            end
        else
            if i>41
                text(1,i,All_Runs_6_Hist(i).Full_name,'Color',rgb('black'),'HorizontalAlignment','center','Fontsize',12,'FontWeight','bold');
            else
                text(1,i,All_Runs_6_Hist(i).Full_name,'Color',rgb('black'),'HorizontalAlignment','center','Fontsize',12,'FontWeight','bold');
            end
        end
        text(1.3,i,All_Runs_6_Hist(i).model,'Color','k','Fontsize',11,'FontWeight','bold');
    else
        % Gerade
        plot([1.1 1.7],[i i],'color',All_Runs_6_Hist(i).Color,'Linewidth',all_Linewidth)
        plot(1.1,i,'o','MarkerEdgeColor',All_Runs_6_Hist(i).Color,'MarkerFaceColor',All_Runs_6_Hist(i).Color,'MarkerSize',17)
        if length(All_Runs_6_Hist(i).Full_name)==1
            if i>41
                text(1.1,i,All_Runs_6_Hist(i).Full_name,'Color',rgb('black'),'HorizontalAlignment','center','Fontsize',12,'FontWeight','bold');
            else
                text(1.1,i,All_Runs_6_Hist(i).Full_name,'Color',rgb('black'),'HorizontalAlignment','center','Fontsize',12,'FontWeight','bold');
            end
        else
            if i>41
                text(1.1,i,All_Runs_6_Hist(i).Full_name,'Color',rgb('black'),'HorizontalAlignment','center','Fontsize',12,'FontWeight','bold');
            else
                text(1.1,i,All_Runs_6_Hist(i).Full_name,'Color',rgb('black'),'HorizontalAlignment','center','Fontsize',12,'FontWeight','bold');
            end
        end
        text(1.7,i,All_Runs_6_Hist(i).model,'Color','k','Fontsize',11,'FontWeight','bold');
    end
end
% Plot Reference
plot([1 1.7],[numel(All_Runs_6_Hist)+4 numel(All_Runs_6_Hist)+4],'color',rgb('black'),'Linewidth',2)
plot(1,numel(All_Runs_6_Hist)+4,'o','MarkerEdgeColor',rgb('black'),'MarkerFaceColor',rgb('black'),'MarkerSize',19)
text(1.8,numel(All_Runs_6_Hist)+4,'HadISST','Color','k','Fontsize',11);

text(1.1,numel(All_Runs_6_Hist)+2,'CMIP6 models','Color','k','Fontsize',16);

ax=gca;
ax.XLim=[1 2.5];
ax.YLim=[1 numel(All_Runs_5_Hist)];
ax.Visible='off';


%% Figure zonal median distribution box plot

Combined_hist(1:32,1)= wrapTo360([All_Runs_5_Hist.posxmax_rel_lons]);
Combined_hist(1:28,2)= wrapTo360([All_Runs_6_Hist.posxmax_rel_lons]);
Combined_hist(29:32,2)=NaN;

Combined_scen(1:31,1)= wrapTo360([All_Runs_5_Scenario.posxmax_rel_lons]);
Combined_scen(1:19,2)= wrapTo360([All_Runs_6_Scenario.posxmax_rel_lons]);
Combined_scen(20:31,2)=NaN;

Fig=figure('visible','on');
Ax_hist_CMIP5CMIP6=axes('parent',Fig);
set(gcf, 'Color', 'White');
set(gcf,'position',[  -922   451   688   103]);

axb1=boxplot(Combined_hist,{'CMIP5','CMIP6'},'orientation', 'horizontal','Widths',0.75);
Lon_names=LookupTable_Longitudenames(round(All_Runs_Pacific(i). Zonal_means_CMIP.Longitude(1:20:end)));
ax=gca;
ax.XLim=[wrapTo360(All_Runs_Pacific(i). Zonal_means_CMIP.Longitude(1)),wrapTo360(All_Runs_Pacific(i). Zonal_means_CMIP.Longitude(end))];
ax.FontSize=15;
ax.YLim=[0.3 2.65];
ax.XTick=[wrapTo360(All_Runs_Pacific(i). Zonal_means_CMIP.Longitude(1:20:end))];
set(gca,'XTickLabel',Lon_names)

h = findobj(gca,'Tag','Box');
p(1)=patch(get(h(1),'XData'),get(h(1),'YData'),color_cmip6,'FaceAlpha',.45);
p(1).EdgeColor='w';
p(2)=patch(get(h(2),'XData'),get(h(2),'YData'),color_cmip5,'FaceAlpha',.45);
p(2).EdgeColor='w';

% Fix and Linewidth
h33 = findobj(gca,'Type','Line','tag','Outliers');for i=1:numel(h33); h33(i).Marker='.'; h33(i).MarkerEdgeColor='None';end
h2 = findobj(gca,'Type','Line','tag','Median');
h2(1).Color=color_cmip6;h2(1).LineWidth=2.5;
h2(2).Color=color_cmip5;h2(2).LineWidth=2.5;
title('Hist')

Fig=figure('visible','on');
Ax_scenario_CMIP5CMIP6=axes('parent',Fig);
set(gcf, 'Color', 'White');
set(gcf,'position',[  -922   451   688   103]);

boxplot(Combined_scen,{'CMIP5','CMIP6'},'orientation', 'horizontal','Widths',0.75)
ax=gca;
ax.XLim=[wrapTo360(All_Runs_Pacific(i). Zonal_means_CMIP.Longitude(1)),wrapTo360(All_Runs_Pacific(i). Zonal_means_CMIP.Longitude(end))];
ax.FontSize=15;
ax.YLim=[0.3 2.65];
ax.XTick=[wrapTo360(All_Runs_Pacific(i). Zonal_means_CMIP.Longitude(1:20:end))];
set(gca,'XTickLabel',Lon_names)

h = findobj(gca,'Tag','Box');
p(1)=patch(get(h(1),'XData'),get(h(1),'YData'),color_cmip6,'FaceAlpha',.45);
p(1).EdgeColor='w';
p(2)=patch(get(h(2),'XData'),get(h(2),'YData'),color_cmip5,'FaceAlpha',.45);
p(2).EdgeColor='w';

% Fix and Linewidth
h33 = findobj(gca,'Type','Line','tag','Outliers');for i=1:numel(h33); h33(i).Marker='.'; h33(i).MarkerEdgeColor='None';end
h2 = findobj(gca,'Type','Line','tag','Median');
h2(1).Color=color_cmip6;h2(1).LineWidth=2.5;
h2(2).Color=color_cmip5;h2(2).LineWidth=2.5;
title('RCP8.5/SSP585')

[h1,p1,add1]=ttest(Combined_hist(~isnan(Combined_hist(:,2)),2),Combined_scen(~isnan(Combined_scen(:,2)),2));
[h2,p2,add2]=ttest(Combined_hist(~isnan(Combined_hist(:,1)),1),Combined_scen(~isnan(Combined_scen(:,1)),1));



%% Put all figures together historical and projections
Fig=figure('visible','on');
set(gcf, 'Color', 'White');
set(gcf,'position',[13         488        1015         497]);

p = panel();
p.pack('h', {0.25 0.65 0.15})
p(1).pack('v',{0.95 0.05})

p(2).pack({[0 0 1 1]});
p(2).pack({[0 1 1 0.1]});
p(2).pack({[0 0 1 0.1]});

p(3).pack('v',{0.95 0.05})


p(1,1).select(Ax_legend_CMIP5);

p(2,1).select(Ax_zavg_obs);Ax_zavg_obs.Title.String=[];
Ax_zavg_obs.YLim=[0 2.65];Ax_zavg_obs.Box='on';
Ax_zavg_obs.YTickLabel{1}=[];

p(2,2).select(Ax_hist_CMIP5CMIP6);Ax_hist_CMIP5CMIP6.Title.String=[];
Ax_hist_CMIP5CMIP6.XTickLabel=[];

p(2,3).select(Ax_scenario_CMIP5CMIP6);Ax_scenario_CMIP5CMIP6.Title.String=[];
Ax_scenario_CMIP5CMIP6.XTickLabel=[];

p(3,1).select(Ax_legend_CMIP6);
p.de.margin=6;
p.fontsize=15;
p.marginbottom=18;

p.marginright=22;
p.marginleft=5;p.marginbottom=18;p.margintop=18;

t1 = annotation('textbox');t1.String=['Historical'];t1.LineStyle='none';t1.Position=get(Ax_zavg_obs,'position');t1.FontSize=16;t1.Position(2)=0.17;
t2 = annotation('textbox');t2.String=['RCP-8.5/SSP5-8.5'];t2.LineStyle='none';t2.Position=get(Ax_scenario_CMIP5CMIP6,'position');t2.FontSize=16;t2.Position(2)=0.09;


save2pdf('./figs/CMIP5_and_CMIP5_zonal_SST_variability_with_histogram_and_projections.pdf');


function [vargout]=plot_ts_patch(time,x1,x2,vargin)
if nargin==4
    color=vargin;
else
    color=[0.9 0.9 0.9];
end
time=time(:);
x1=x1(:);
x2=x2(:);

% Replace infinities
x1(isinf(x1))=NaN;
x2(isinf(x2))=NaN;


x11=Get_consecutives(x1,x1,1);
x22=Get_consecutives(x2,x2,1);

both_have_data=x11.*x22;

pos1=find(both_have_data,1,'first');
pos2=find(both_have_data,1,'last');

hp=patch( [time(pos1:pos2)' fliplr(time(pos1:pos2)')],[x1(pos1:pos2)' fliplr(x2(pos1:pos2)')],color);
if ~isempty(hp)
    hp.LineStyle='none';
end

vargout=hp;
end



function [logical_consec,Exact_logical_consec]=Get_consecutives(A,threshold,consecutives,vargin)
% Returns Consecutive values of a vector 
% or matrix above or below a certain threshold
% input: A: column vector or matrix
% threshold : critical value
% consectvies: number of consectuive values
% above or below the threshold
% output: logical of A
if nargin==4;
  fnc=vargin;
else
    fnc=@ge;
end

[siz_a,siz_b]=size(A);

% MFreund 29.10.2018
%if siz_b || siz_a ==1
% Columnvec
%A=A(:);
%end


if siz_b==1 || siz_a ==1
% Columnvec
A=A(:);
end

%logical_consec = false(siz_a,siz_b);
ConsOrMore = false(siz_a*siz_b,1);

% Find days more than a threshold of 5:
%aboveThreshold = double(A >=threshold');
if size(A,2)==size(threshold,2)
     aboveThreshold = double(bsxfun(fnc, A, threshold));
else
    aboveThreshold = double(bsxfun(fnc, A, threshold'));
end

% Make a moving window of 3 time steps to count the number of time steps
windowWidth = consecutives; %3 consecutuve values

counts = conv2(aboveThreshold', ones(1, windowWidth), 'full');

tenOrMore = counts >=windowWidth;

[a,b]=find(tenOrMore==1);

startInd = sub2ind(size(A), b,a)-(windowWidth-1);
endInd = sub2ind(size(A), b,a);


v = zeros(1,max(endInd)+1);   %# An array of zeroes
v(startInd) = 1;              %# Place 1 at the starts of the intervals
v(endInd+1) = v(endInd+1)-1;  %# Add -1 one index after the ends of the intervals
v =logical(cumsum(v));  %# Perform a cumulative sum and find the nonzero entries

ConsOrMore(v)=true;

logical_consec=reshape(ConsOrMore,siz_a,siz_b);

% Exact and only window length 13.12.2018
Exact_ConsOrMore = false(siz_a*siz_b,1);
AA=[0 double(ConsOrMore)' 0];
BB = [0 repmat(1,1,windowWidth) 0];
Index  = strfind(AA, BB);

%SuperIndex=[Index(:);Index(:)+(windowWidth-1)];
SuperIndex=[Index(:):Index(:)+(windowWidth-1)];

startInd = Index(:);
endInd = Index(:)+(windowWidth-1);

vv = zeros(1,max(endInd)+1);   %# An array of zeroes
vv(startInd) = 1;              %# Place 1 at the starts of the intervals
vv(endInd+1) = vv(endInd+1)-1;  %# Add -1 one index after the ends of the intervals
vv =logical(cumsum(vv));  %# Perform a cumulative sum and find the nonzero entries


Exact_ConsOrMore(vv)=true;

Exact_logical_consec=reshape(Exact_ConsOrMore,siz_a,siz_b);
end


