;*****************************************************
; Harun Rashid, CSIRO, Harun.Rashid@csiro.au; 2019.
;
load "~/ncl/scripts/nclscripts/mynclfuncs.ncl"
;******************************************************
;
begin

  ;yr0 = 1850
  yr0 = 1950
  yr1 = 2005
  yr2 = 2100

  ft = addfile("CMIP5_ClimChangeSig_ts.nc","r")
  ts_em_trend = ft->ts_em_trend
  time0 = ft->time
  times = todouble(time0)
  times@units = time0@units
  tinds = getTimeIndex2(times,yr0,yr1)
  t0 = tinds(0)
  t1 = tinds(1)

  f1 = addfile("CMIP5_ENSO-IOD_hist_ts_Indices.nc","r")
  f2 = addfile("CMIP5_ENSO-IOD_rcp85_ts_Indices.nc","r")

  mods0 = getfilevarnames(f1)
  nvar0 = dimsizes(mods0)
  idxs0 = new(nvar0,"integer")
  j = 0
  do i = 0, nvar0-1
     if (isStrSubset(mods0(i),"tsF_")) then
        idxs0(j) = i
        j = j+1
     end if
  end do 
  idxs = idxs0(:j-1)
  vars1 = mods0(idxs)

  mods2 = getfilevarnames(f2)
  nvar2 = dimsizes(mods2)
  idxs2 = new(nvar2,"integer")
  j = 0
  do i = 0, nvar2-1
     if (isStrSubset(mods2(i),"tsF_")) then
        idxs2(j) = i
        j = j+1
     end if
  end do 
  idxs1 = idxs2(:j-1)
  vars2 = mods2(idxs1)

  vars = getCommonList(vars1,vars2)
  nvar = dimsizes(vars)

  if (yr0 .eq. 1850) then
     outFile = "CMIP5_SeasPhaseLock_HistScen.nc"
  else
     outFile = "CMIP5_SeasPhaseLock_HistScen_v2.nc"
  end if
  if (isfilepresent(outFile)) then
     system("\rm "+outFile)
  end if
  fo = addfile(outFile,"c")
  fo@models = oneDtostring(vars)
  fo@desc = "Standard deviations of the Nino3.4 index computed at each calendar months."

  nidx = 1    ; process Nino3.4 index
  sidx = "Nino3.4 index"

  ntim1 = (yr1-yr0+1)*12
  ntim2 = (yr2-yr1)*12
  df1 = new((/nvar,12,ntim1/12/), "float")
  df2 = new((/nvar,12,ntim2/12/), "float")

  do i = 0, nvar-1
 
     temp1 = f1->$vars(i)$(nidx,t0:t1)
     temp1 = temp1 - tofloat(ts_em_trend(t0:t1))
     temp1 = dtrend(temp1,False)
     temp2 = f2->$vars(i)$(nidx,:)
     temp2 = temp2 - tofloat(ts_em_trend(t1+1:))
     temp2 = dtrend(temp2,False)
     df1(i,:,:) = transpose(onedtond(temp1,(/ntim1/12,12/)))
     df2(i,:,:) = transpose(onedtond(temp2,(/ntim2/12,12/)))

  end do

  df1 = dim_rmvmean(df1)
  df2 = dim_rmvmean(df2)

  df1@long_name = "Nino3.4 index for calendar months"
  df1@units = "C"
  df1!0 = "nmod"
  df1!1 = "monc"
  df1!2 = "time"
  df1&nmod = ispan(0,nvar-1,1)
  df1&nmod@long_name = "Number of models"
  df1&monc = ispan(0,11,1)
  df1&monc@long_name = "Calendar months"
  copy_VarMeta(df1,df2)
  time1 = temp1&time
  df1&time = time1(6::12)
  time2 = temp2&time
  df2&time = time2(6::12)

  df = array_append_record (df1(time|:,nmod|:,monc|:), df2(time|:,nmod|:,monc|:), 0)

  df1_std = dim_stddev_Wrap(df1)
  df2_std = dim_stddev_Wrap(df2)

  df1_std@long_name = "Nino3.4 stddevs for calendar months (Hist)"
  df1_std@units = "C"
  df2_std@long_name = "Nino3.4 stddevs for calendar months (RCP8.5)"
  df2_std@units = "C"

  td = 1.0                     ; 1 month
  iopt = 0                     ; remove mean 
  jave = 11                                    ; Daniell smoother of length 31
  pct  = 0.1                                   ; taper 10% of data

  spec1 = new((/nvar,ntim1/2/), "float")
  spec2 = new((/nvar,ntim2/2/), "float")
  stdev1 = new(nvar,"float")
  stdev2 = new(nvar,"float")

  do i = 0, nvar-1
     tmp1 = ndtooned(transpose(df1(i,:,:)))
     tmp2 = ndtooned(transpose(df2(i,:,:)))
     stdev1(i) = variance(tmp1)
     stdev2(i) = variance(tmp2)
     ;dof1 = specx_anal(tmp1/stdev1(i),iopt,jave,pct)
     ;dof2 = specx_anal(tmp2/stdev2(i),iopt,jave,pct)
     dof1 = specx_anal(tmp1,iopt,jave,pct)
     dof2 = specx_anal(tmp2,iopt,jave,pct)
     spec1(i,:) = dof1@spcx
     spec2(i,:) = dof2@spcx
  end do

  spec1!0 = "nmod"
  spec1!1 = "freq1"
  spec1@long_name = "Power spectrum of the normalised Nino3.4 index"
  spec1&nmod = df1&nmod
  copy_VarMeta(spec1,spec2)
  spec1&freq1 = dof1@frq
  spec2!1 = "freq2"
  spec2&freq2 = dof2@frq
  spec1&freq1@units = "cyc/month"
  spec2&freq2@units = "cyc/month"

  stdev1@long_name = "Variances of the Nino3.4 index"
  stdev1@units = "C**2"
  stdev1!0 = "nmod"
  stdev1&nmod = df1&nmod
  copy_VarMeta(stdev1,stdev2)

  sidx1 = (/0,1,2,10,11/)               ; indices for NDJFM
  sst1 = dim_avg_n_Wrap(df1(:,sidx1,:),1) ; ts for NDJFM
  nlag = 15
  sst1_acr = esacr(sst1,nlag)
  sst1_acr@long_name = "Nino3.4 index auto-correlations for NDJFM (Hist)"
  sst1_acr@units = ""
  sst1_acr!0 = "nmod"
  sst1_acr!1 = "lag"
  sst1&nmod = ispan(0,nvar-1,1)
  sst1&nmod@long_name = "Number of models"
  sst1_acr&lag = ispan(0,nlag,1)
  sst1_acr&lag@long_name = "Lags in month"

  sst2 = dim_avg_n_Wrap(df2(:,sidx1,:),1) ; ts for NDJFM
  nlag = 15
  sst2_acr = esacr(sst2,nlag)
  copy_VarMeta(sst1_acr,sst2_acr)
  sst2_acr@long_name = "Nino3.4 index auto-correlations for NDJFM"

  fo->nino34_anom = df
  fo->nino34_hist_std = df1_std
  fo->nino34_rcp85_std = df2_std
  fo->nino34_hist_acr = sst1_acr
  fo->nino34_rcp85_acr = sst2_acr
  fo->nino34_hist_spc = spec1
  fo->nino34_rcp85_spc = spec2
  fo->nino34_hist_var = stdev1
  fo->nino34_rcp85_var = stdev2
  
end

