; Ghyslaine Boschat, BoM, Ghyslaine.Boschat@bom.gov.au, 2019
;
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/shea_util.ncl"

begin

  dir = "/g/data/w48/gab563/CMIP6/Indices/"

  ModelList_CMIP5 = (/"bcc-csm1-1","bcc-csm1-1-m","BNU-ESM","CanESM2","CMCC-CESM","CMCC-CM","CMCC-CMS","CNRM-CM5","inmcm4","IPSL-CM5A-LR","IPSL-CM5A-MR","IPSL-CM5B-LR","MIROC5","MIROC-ESM","MIROC-ESM-CHEM","HadGEM2-CC","MPI-ESM-LR","MPI-ESM-MR","MRI-CGCM3","MRI-ESM1","GISS-E2-H","GISS-E2-H-CC","GISS-E2-R","GISS-E2-R-CC","CCSM4","NorESM1-M","NorESM1-ME","HadGEM2-AO","GFDL-CM3","GFDL-ESM2G","GFDL-ESM2M","CESM1-BGC","CESM1-CAM5"/)

  ModelList_CMIP6 = (/"ACCESS-CM2", "ACCESS-ESM1-5", "AWI-CM-1-1-MR", "BCC-CSM2-MR", "CAMS-CSM1-0", "CanESM5", "CESM2", "CESM2-WACCM", "CNRM-CM6-1", "CNRM-ESM2-1", "EC-Earth3-Veg", "FGOALS-g3", "GFDL-CM4", "IPSL-CM6A-LR", "MIROC6", "MIROC-ES2L", "MPI-ESM1-2-HR", "MRI-ESM2-0", "NESM3", "UKESM1-0-LL"/)

  years = ispan(1979, 2099, 1)
  seasons = (/"JFM", "FMA", "MAM", "AMJ", "MJJ", "JJA", "JAS", "ASO", "SON", "OND", "NDJ", "DJF"/)

  ; 1) SAM and trends per season

  SAM_CMIP5 = new((/dimsizes(seasons), dimsizes(ModelList_CMIP5), 220/), float)
  SAM_CMIP6 = new((/dimsizes(seasons), dimsizes(ModelList_CMIP6), 250/), float)

  do imodel = 0, dimsizes(ModelList_CMIP5) - 1
    in = addfile(dir + "CMIP5/Stand/SAM_1m_188001-210012_" + ModelList_CMIP5(imodel) + "_hist+rcp85.nc", "r")
    temp1 = in->SAM(0:2639)
    temp2 = month_to_seasonN(temp1, seasons)
    SAM_CMIP5(:,imodel,:) = temp2(:,0:219)
    copy_VarCoords(temp2, SAM_CMIP5(:,imodel,:))
    delete([/in, temp1, temp2/])
  end do

  do imodel = 0, dimsizes(ModelList_CMIP6) - 1   
    in = addfile(dir + "Stand/ssp585/SAM_1m_185001-210012_" + ModelList_CMIP6(imodel) + "_hist+ssp585.nc", "r")
    temp1 = in->SAM(0:2999)
    temp2 = month_to_seasonN(temp1, seasons)
    SAM_CMIP6(:,imodel,:) = temp2(:,0:249)
    copy_VarCoords(temp2, SAM_CMIP6(:,imodel,:))          
    delete([/in, temp1, temp2/])
  end do

  trend_CMIP5 = new((/dimsizes(seasons), dimsizes(ModelList_CMIP5)/), float)
  trend_CMIP6 = new((/dimsizes(seasons), dimsizes(ModelList_CMIP6)/), float)

  do iseas = 0, dimsizes(seasons) - 1
    do k = 0, dimsizes(ModelList_CMIP5) - 1
      trend_CMIP5(iseas,k) =  regCoef_n(years, SAM_CMIP5(iseas,k,99:219), 0, 0)*dimsizes(years)
    end do
    do l = 0, dimsizes(ModelList_CMIP6) - 1
      trend_CMIP6(iseas,l) = regCoef_n(years, SAM_CMIP6(iseas,l,129:249), 0, 0)*dimsizes(years)
    end do
  end do
  
  ; 2) PLOT
         
  mnmx_CMIP5 = new((/3,dimsizes(seasons)+1/), float) ; calculate min/max enveloppe
  mnmx_CMIP5(0,0:dimsizes(seasons)-1) = dim_min_n_Wrap(trend_CMIP5, 1)
  mnmx_CMIP5(1,0:dimsizes(seasons)-1) = dim_max_n_Wrap(trend_CMIP5, 1)
  mnmx_CMIP5(2,0:dimsizes(seasons)-1) = dim_avg_n_Wrap(trend_CMIP5, 1)
  mnmx_CMIP5(0,dimsizes(seasons)) = mnmx_CMIP5(0,0)    ; repeat the first season at the end of the timeseries
  mnmx_CMIP5(1,dimsizes(seasons)) = mnmx_CMIP5(1,0)
  mnmx_CMIP5(2,dimsizes(seasons)) = mnmx_CMIP5(2,0)

  mnmx_CMIP6 = new((/3,dimsizes(seasons)+1/), float)
  mnmx_CMIP6(0,0:dimsizes(seasons)-1) = dim_min_n_Wrap(trend_CMIP6, 1)
  mnmx_CMIP6(1,0:dimsizes(seasons)-1) = dim_max_n_Wrap(trend_CMIP6, 1)
  mnmx_CMIP6(2,0:dimsizes(seasons)-1) = dim_avg_n_Wrap(trend_CMIP6, 1)
  mnmx_CMIP6(0,dimsizes(seasons)) = mnmx_CMIP6(0,0)
  mnmx_CMIP6(1,dimsizes(seasons)) = mnmx_CMIP6(1,0)
  mnmx_CMIP6(2,dimsizes(seasons)) = mnmx_CMIP6(2,0)

  wks = gsn_open_wks("ps", dir + "../figures/plot_trend_SAM_seasons_1979-2099_enveloppes_CMIP56")

  seas = ispan(0,12,1)
  line_plot = new(2, graphic)
  env_plot = new(2, graphic)
  
  res                             = True
  res@gsnDraw                     = False
  res@gsnFrame                    = False
  res@vpHeightF                   = 0.4
  res@vpWidthF                    = 0.7
  res@trYMinF                     = -1                                 
  res@trYMaxF                     = 5 
  res@tmXBMode                    = "Explicit"
  res@tmXBValues                  = seas
  res@tmXBLabels                  = (/"JFM", "FMA", "MAM", "AMJ", "MJJ", "JJA", "JAS", "ASO", "SON", "OND", "NDJ", "DJF", ""/)
  res@tmXBLabelAngleF             = 45.0
  res@tmXBLabelDeltaF             = 0.55
  res@tmXBLabelFontHeightF        = 0.02
  res@tmXBLabelJust               = "CenterRight"
  res@xyMonoLineColor             = False 
  res@tiYAxisString               = "Trend (stddev/121yrs)"
  res@txFontHeightF               = 0.01

  res@tiMainString                = "c)"
  res@tiMainPosition              = "Left"
  res@xyLineColor                 = "Blue"
  res@xyLineThicknesses           = (/3./)
  res@xyDashPatterns              = (/0./)
  line_plot(0) = gsn_csm_xy (wks,seas,mnmx_CMIP5(2,:),res)     
  res@gsnXYFillColors             = "LightBlue" 
  res@xyLineColor                 = -1
  env_plot(0)  = gsn_csm_xy (wks,seas,mnmx_CMIP5(0:1,:),res)

  res@tiYAxisString               = ""
  res@tiMainString                = "d)"
  res@xyLineColor                 = "Red"
  res@xyLineThicknesses           = (/3./)
  res@xyDashPatterns              = (/0./)
  line_plot(1) = gsn_csm_xy (wks,seas,mnmx_CMIP6(2,:),res)   
  res@gsnXYFillColors             = "pink1"
  res@xyLineColor                 = -1
  env_plot(1)  = gsn_csm_xy (wks,seas,mnmx_CMIP6(0:1,:),res)

  overlay(line_plot(0),env_plot(0))
  overlay(line_plot(1),env_plot(1))
  
  res_line                        = True
  res_line@gsLineDashPattern      = 0.
  res_line@gsLineThicknessF       = 1.
  yy = (/0,0,0,0,0,0,0,0,0,0,0,0,0/)
  yaxis0 = gsn_add_polyline(wks, line_plot(0), seas, yy, res_line) ; add y=0 axis
  yaxis1 = gsn_add_polyline(wks, line_plot(1), seas, yy, res_line)
  
  pres                        = True
  pres@gsnMaximize            = True
  gsn_panel(wks,line_plot,(/1,2/),pres)	

end 




