#!/usr/bin/env python
#
# Copyright 2019 Scott Wales
#
# Author: Scott Wales <scott.wales@unimelb.edu.au>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import os
import subprocess
import json
import sys
import xarray
from pathlib import Path
from dask.diagnostics import ProgressBar
import pandas

def prepare_tas_files(files):
    tmp = Path(os.environ['TMPDIR'])

    tasmin = tmp / 'tasmin.nc'
    tasmax = tmp / 'tasmax.nc'

    p0 = subprocess.Popen(['cdo','copy',*sorted(files['tasmin']), tasmin])
    p1 = subprocess.Popen(['cdo','copy',*sorted(files['tasmax']), tasmax])

    p0.wait()
    p1.wait()

    return tasmin, tasmax, ''

if __name__ == '__main__':
    group = sys.argv[1]

    r = json.load(sys.stdin)[group]

    exp = r['historical']
    name = exp['name']
    print("Analysing", name)

    inputs = prepare_tas_files(exp)

    ds = xarray.open_dataset(inputs[0])
    suffix = name + '_' + pandas.to_datetime(ds.time.values[0]).strftime('%Y%m%d') + '-' +  pandas.to_datetime(ds.time.values[-1]).strftime('%Y%m%d')

    output = Path('/g/data/w40/saw562/climpact') / name
    output.mkdir(exist_ok=True)

    subprocess.run(['Rscript','climpact2.ncdf.wrapper.r', *inputs, '', output, suffix], check=True)

    for child in output.iterdir():
        if child.name.endswith('.sample_historical_NA_1991-2010.nc'):
            newname = child.name.replace('sample_historical_NA_1991-2010', suffix)

            child.rename(output / newname)
