#!/usr/bin/env python
#
# Copyright 2019 Scott Wales
#
# Author: Scott Wales <scott.wales@unimelb.edu.au>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import os
import subprocess
import json
import sys
import xarray
from pathlib import Path
from dask.diagnostics import ProgressBar
import shlex

def print_and_run(args, **kwargs):
    print(' '.join([shlex.quote(a) for a in args]))
    r = subprocess.run(args, **kwargs)

def prepare_files(files):
    tmp = Path(os.environ['TMPDIR'])

    tasmin = tmp / 'tasmin.nc'
    tasmax = tmp / 'tasmax.nc'
    pr = tmp / 'pr.nc'

    waits = []

    if len(files['tasmin']) > 0:
        waits.append(subprocess.Popen(['cdo','copy',*sorted(files['tasmin']), tasmin]))
        waits.append(subprocess.Popen(['cdo','copy',*sorted(files['tasmax']), tasmax]))
    else:
        tasmin = ''
        tasmax = ''

    if len(files['pr']) > 0:
        waits.append(subprocess.Popen(['cdo','copy',*sorted(files['pr']), pr]))
    else:
        pr = ''

    for w in waits:
        w.wait()

    return tasmin, tasmax, pr

if __name__ == '__main__':
    run = sys.argv[1]

    j = json.load(sys.stdin)

    for k, v in j.items():
        if 'historical' not in v:
            continue
        for ek, ev in v.items():
            if ev['name'] == run:
                exp = ev
                historical = v['historical']['name']

    print('Historical job is ', historical)

    thresholds = Path('/g/data/w40/saw562/climpact') / historical / 'climpact_thresholds.nc'

    if not thresholds.is_file():
        raise Exception(f"Thresholds file {thresholds} missing")

    name = exp['name']
    print(name)

    inputs = prepare_files(exp)

    output = Path('/g/data/w40/saw562/climpact') / name
    output.mkdir(exist_ok=True)

    subprocess.run(['Rscript','climpact2.ncdf.wrapper.r', *inputs, thresholds, output], check=True)
        



