#!/usr/bin/env python
#
# Copyright 2019 Scott Wales
#
# Author: Scott Wales <scott.wales@unimelb.edu.au>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from clef.db import connect, Session
import clef.model as m
import json
import sys

def experiment_variable(session, source_dataset, variable_id):
    """
    Create a list record of all the files in the 'variable_id'
    variant of source_dataset
    """
    s = session
    exp = source_dataset

    match = (s.query(m.C6Dataset)
            .filter(m.C6Dataset.project == exp.project)
            .filter(m.C6Dataset.activity_id == exp.activity_id)
            .filter(m.C6Dataset.institution_id == exp.institution_id)
            .filter(m.C6Dataset.source_id == exp.source_id)
            .filter(m.C6Dataset.experiment_id == exp.experiment_id)
            .filter(m.C6Dataset.frequency == exp.frequency)
            .filter(m.C6Dataset.variant_label == exp.variant_label)
            .filter(m.C6Dataset.member_id == exp.member_id)
            .filter(m.C6Dataset.grid_label == exp.grid_label)
            .filter(m.C6Dataset.variable_id == variable_id)
            ).one_or_none()

    if match is None:
        return []

    return [p.path for p in s.query(m.Path.path).filter(m.Path.c6dataset.contains(match))]

def input_record(session, source_dataset, experiment_id='historical'):
    """
    Create a dict record of all the files in source_dataset for variables
    tasmin, tasmax and pr
    """

    s = session
    exp = source_dataset

    tasmin_files = experiment_variable(session, source_dataset, 'tasmin')
    tasmax_files = experiment_variable(session, source_dataset, 'tasmax')
    pr_files = experiment_variable(session, source_dataset, 'pr')

    name = f'{exp.source_id}_{exp.experiment_id}_{exp.variant_label}_{exp.grid_label}'

    record = (
        exp.experiment_id,
        {
            'name': name,
            'tasmin': tasmin_files,
            'tasmax': tasmax_files,
            'pr': pr_files,
        },
        )

    return record

if __name__ == '__main__':
    connect()
    s = Session()

    # Grab the experiments - historical and SSPs with daily tasmin, tasmax, pr
    q = (s.query(m.C6Dataset)
            .filter(m.C6Dataset.project == 'CMIP6')
            .filter(m.C6Dataset.experiment_id == 'historical')
            .filter(m.C6Dataset.frequency == 'day')
            )

    output = {}

    for exp in q:
        # Find all experiment_ids like this one
        matches = (s.query(m.C6Dataset)
                .filter(m.C6Dataset.project == exp.project)
                .filter(m.C6Dataset.activity_id.in_(['CMIP','ScenarioMIP']))
                .filter(m.C6Dataset.experiment_id != 'piControl')
                .filter(m.C6Dataset.institution_id == exp.institution_id)
                .filter(m.C6Dataset.source_id == exp.source_id)
                .filter(m.C6Dataset.frequency == exp.frequency)
                .filter(m.C6Dataset.variant_label == exp.variant_label)
                .filter(m.C6Dataset.member_id == exp.member_id)
                .filter(m.C6Dataset.grid_label == exp.grid_label)
                .filter(m.C6Dataset.variable_id == exp.variable_id)
                )

        group = f'{exp.source_id}_{exp.variant_label}_{exp.grid_label}'
        records = {}

        for match in matches:
            if match.experiment_id != 'piControl':
                name, files = input_record(s, match)
                if len(files['tasmin']) > 0 or len(files['pr']) > 0:
                    records[name] = files

        output[group] = records

    print(json.dumps(output, indent=4))

        # tmp = Path(os.environ['TMPDIR'])

        # p0 = subprocess.Popen(['cdo','copy',*[x.path for x in tasmin_files], tmp/'tasmin.nc'])
        # p1 = subprocess.Popen(['cdo','copy',*[x.path for x in tasmax_files], tmp/'tasmax.nc'])
        # p2 = subprocess.Popen(['cdo','copy',*[x.path for x in pr_files], tmp/'pr.nc'])

        # p0.wait()
        # p1.wait()
        # p2.wait()

        # subprocess.run(['Rscript', 'climpact2.ncdf.thresholds.wrapper.r', tmp/'tasmin.nc', tmp/'tasmax.nc', tmp/'pr.nc', tmp/'threshold.nc'])


    # Thresholds are generated from the historical

    # Collate the inputs using cdo

    # Use the thresholds on the experiments

    # For each experiment

    # If not historical, collate the inputs using cdo (historical was done before)

    # Calculate the indices
