; Margot Bador, UNSW, m.bador@unsw.edu.au, 2020.
;
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"

begin
  ;
  ;
;########### Miscellaneous ##############################################"
  ; 
  indices            = (/ "tnn", "rx1day", "txx", "r10mm", "wsdi", "cdd" /)
  ;
  pathoutfig         = "/g/data/w40/mba561/figures/ncl/first_look_at_CMIP6_Australia/"
  namefig            = "Figure_11"
  ;
  ;
;#######################################################################"
  ;
  ;
  nindices           = dimsizes( indices )
  ;                     
  ; ## Load model name list
  li_rcp85           = "list_models_rcp85_for_indices_CMIP5.txt"
  models_rcp85       = asciiread( li_rcp85,-1,"string" )
  nmodels_rcp85      = dimsizes( models_rcp85 )
  li_ssp585          = "list_models_ssp585_for_indices_CMIP6.txt"
  models_ssp585      = asciiread( li_ssp585,-1,"string" )
  nmodels_ssp585     = dimsizes( models_ssp585 )
  ;
  ;              
  ; Prep loading the indice of every datasets
  pathin_root_CMIP5  = "/g/data/w40/mba561/cmip_regridded/CMIP5/"
  pathin_root_CMIP6  = "/g/data/w40/mba561/cmip_regridded/CMIP6/"
  ;
  ;
  ;                     
  ; ## Load mask
  pathin           = "/g/data/w40/mba561/cmip_regridded/"
  filein           = "fractional_land.1.5-deg.nc"
  ff               = addfile( pathin+filein, "r" )
  msk              = ff->data( time|0,{lat|-45:-10},{lon|110:155} )
  msk              := msk*msk@scale_factor
  ;
  ;
  ;
  ;
  ;
  ;
  ; ---------------------------------------------------------------------------------------------------------
  ;                  Prepare plot
  ; ---------------------------------------------------------------------------------------------------------
  ;
  ;
  ; Prep the  plot
  qual               = "png" ; png ps
  wks                = gsn_open_wks( qual, pathoutfig+namefig )
  plots              = new( 6, graphic )
  plots_a            = new( 6, graphic )
  dumtext_0          = new( 6, graphic )
  dumtext_1          = new( 6, graphic )
  annoid_0           = new( 6, graphic )
  annoid_1           = new( 6, graphic )
  ;
  res               = True  
  res@gsnDraw       = False
  res@gsnFrame      = False
  res@gsnAddCyclic  = False
  res@cnFillOn      = True
  res@cnLinesOn     = False
  res@cnLineLabelsOn= False
  ;
  res@gsnStringFontHeightF = 0.03
  res@lbLabelFontHeightF   = 0.03
  res@tmXBLabelFontHeightF = 0.025
  res@tmXTLabelFontHeightF = 0.025
  res@tmYLLabelFontHeightF = 0.025
  res@tmYRLabelFontHeightF = 0.025
  ;
  ; raster
  res@cnFillMode     = "RasterFill"
  res@mpOceanFillColor = "gray92" 
  res@mpFillDrawOrder  = "PreDraw"
  res@mpFillColors   = (/ -1,0,-1,-1  /)
  ; plot in a box 
  res@mpMinLatF      = -45
  res@mpMaxLatF      = -10
  res@mpMinLonF      = 110
  res@mpMaxLonF      = 155
  ;
  ;
  ;
  ; ---------------------------------------------------------------------------------------------------------
  ;                  For each index
  ; ---------------------------------------------------------------------------------------------------------
  ;
  do id              = 0, nindices - 1
    ;
    index            = indices( id )
    print(" ")
    print(" ")
    print(" --------------- ")
    print(" "+index)
    ;
    ;
    ; ---------------------------------------------------------------------------------------------------------
    ;                  CMIP5 - rcp85
    ; ---------------------------------------------------------------------------------------------------------
    ;
    ; Loop through datasets  
    do m               = 0, nmodels_rcp85 - 1
      ;
      model            = models_rcp85( m )
      ;
      ; ########################
      ; ### Historical
      ; ########################
      ;
      pathin           = pathin_root_CMIP5+"historical/"
      filein           = systemfunc( "ls "+pathin+index+"ETCCDI_yr_"+model+"_*" )
      ff               = addfile( filein, "r" )
      ;
      ti               = ff->time
      cal              = cd_calendar( ti, 0 )
      yrs              = cal( :,0 )
      i_fyr            = ind( yrs.eq.1995 )
      i_lyr            = ind( yrs.eq.2005 )
      delete([/ ti, cal, yrs /])
      ;
      var_histo_part1  = ff->$(index+"ETCCDI")$( time|i_fyr:i_lyr,{lat|-45:-10},{lon|110:155} )
      delete([/ pathin, filein, ff, i_fyr, i_lyr /])
      ;
      if m.eq.0 then
        nyears         = 2014 - 1995 + 1
        nlat           = dimsizes( var_histo_part1&lat )
        nlon           = dimsizes( var_histo_part1&lon )
        histo_all_CMIP5       = new( (/ nmodels_rcp85, nyears, nlat, nlon /), float, var_histo_part1@_FillValue )
        histo_all_CMIP5!0     = "models"
        histo_all_CMIP5!1     = "years"
        histo_all_CMIP5&years = ispan( 1995, 2014, 1 )
        histo_all_CMIP5!2     = "lat"
        histo_all_CMIP5&lat   = var_histo_part1&lat
        histo_all_CMIP5!3     = "lon"
        histo_all_CMIP5&lon   = var_histo_part1&lon
        units                 = var_histo_part1@units
        histo_all_CMIP5_masked= histo_all_CMIP5
        if units.eq."degrees_C" then
          units               := "~S~o~N~C"
        end if
        delete( nyears )
      end if
      ;
      histo_all_CMIP5( models|m,{years|1995:2005},lat|:,lon|: ) = (/ var_histo_part1 /)
      ;
      ; Mask
      msk_conf         = conform( var_histo_part1, msk, (/ 1,2 /) )
      var_histo_part1_m= where( msk_conf.ge.0.95, var_histo_part1, var_histo_part1@_FillValue )
      histo_all_CMIP5_masked( models|m,{years|1995:2005},lat|:,lon|: ) = (/ var_histo_part1_m /)
      delete([/ msk_conf, var_histo_part1, var_histo_part1_m /])
      ;
      ;
      ; ########################
      ; ### RCP8.5
      ; ########################
      ;
      pathin           = pathin_root_CMIP5+"rcp85/"
      filein           = systemfunc( "ls "+pathin+index+"ETCCDI_yr_"+model+"_*" )
      ff               = addfile( filein, "r" )
      ;
      ti               = ff->time
      cal              = cd_calendar( ti, 0 )
      yrs              = cal( :,0 )
      i_fyr            = ind( yrs.eq.2006 )
      i_lyr            = ind( yrs.eq.2014 )
      delete([/ ti, cal, yrs /])
      ;
      var_histo_part2  = ff->$(index+"ETCCDI")$( time|i_fyr:i_lyr,{lat|-45:-10},{lon|110:155} )
      delete([/ i_fyr, i_lyr /])
      ;
      histo_all_CMIP5( models|m,{years|2006:2014},lat|:,lon|: ) = (/ var_histo_part2 /)
      ;
      ; Mask
      msk_conf         = conform( var_histo_part2, msk, (/ 1,2 /) )
      var_histo_part2_m= where( msk_conf.ge.0.95, var_histo_part2, var_histo_part2@_FillValue )
      histo_all_CMIP5_masked( models|m,{years|2006:2014},lat|:,lon|: ) = (/ var_histo_part2_m /)
      delete([/ msk_conf, var_histo_part2, var_histo_part2_m /])
      ;
      if m.eq.0 then
        nyears         = 2099 - 2080 + 1
        rcp85_all_CMIP5       = new( (/ nmodels_rcp85, nyears, nlat, nlon /), float, histo_all_CMIP5@_FillValue )
        rcp85_all_CMIP5!0     = "models"
        rcp85_all_CMIP5!1     = "years"
        rcp85_all_CMIP5&years = ispan( 2080, 2099, 1 )
        rcp85_all_CMIP5!2     = "lat"
        rcp85_all_CMIP5&lat   = histo_all_CMIP5&lat
        rcp85_all_CMIP5!3     = "lon"
        rcp85_all_CMIP5&lon   = histo_all_CMIP5&lon
        rcp85_all_CMIP5_masked= rcp85_all_CMIP5
        delete( nyears )
      end if
      ;
      ti               = ff->time
      cal              = cd_calendar( ti, 0 )
      yrs              = cal( :,0 )
      i_fyr            = ind( yrs.eq.2080 )
      i_lyr            = ind( yrs.eq.2099 )
      delete([/ ti, cal, yrs /])
      ;
      var_rcp85        = ff->$(index+"ETCCDI")$( time|i_fyr:i_lyr,{lat|-45:-10},{lon|110:155} )
      delete([/ pathin, filein, ff, i_fyr, i_lyr /])
      ;
      rcp85_all_CMIP5( models|m,{years|2080:2099},lat|:,lon|: ) = (/ var_rcp85 /)
      ;
      ; Mask
      msk_conf         = conform( var_rcp85, msk, (/ 1,2 /) )
      var_rcp85_m      = where( msk_conf.ge.0.95, var_rcp85, var_rcp85@_FillValue )
      rcp85_all_CMIP5_masked( models|m,{years|2080:2099},lat|:,lon|: ) = (/ var_rcp85_m /)
      delete([/ msk_conf, var_rcp85, var_rcp85_m /])
      ;
      delete( model )
    end do ;  models rcp85
    ;
    ;
    ;
    ;
    ; ---------------------------------------------------------------------------------------------------------
    ;                  CMIP6 - ssp585
    ; ---------------------------------------------------------------------------------------------------------
    ;
    ;
    ; Loop through datasets  
    do m               = 0, nmodels_ssp585 - 1
      ;
      model            = models_ssp585( m )
      ;
      ; ########################
      ; ### Historical
      ; ########################
      ;
      pathin           = pathin_root_CMIP6+"historical/"
      filein           = systemfunc( "ls "+pathin+index+"_ANN_climpact."+model+"_*" )
      ff               = addfile( filein, "r" )
      ti               = ff->time
      cal              = cd_calendar( ti, 0 )
      yrs              = cal( :,0 )
      i_fyr            = ind( yrs.eq.1995 )
      i_lyr            = ind( yrs.eq.2014 )
      delete([/ ti, cal, yrs /])
      ;
      var_histo        = ff->$index$( time|i_fyr:i_lyr,{lat|-45:-10},{lon|110:155} )
      delete([/ pathin, filein, ff, i_fyr, i_lyr /])
      ;
      if m.eq.0 then
        nyears         = 2014 - 1995 + 1
        nlat           = dimsizes( var_histo&lat )
        nlon           = dimsizes( var_histo&lon )
        histo_all_CMIP6       = new( (/ nmodels_ssp585, nyears, nlat, nlon /), float, var_histo@_FillValue )
        histo_all_CMIP6!0     = "models"
        histo_all_CMIP6!1     = "years"
        histo_all_CMIP6&years = ispan( 1995, 2014, 1 )
        histo_all_CMIP6!2     = "lat"
        histo_all_CMIP6&lat   = var_histo&lat
        histo_all_CMIP6!3     = "lon"
        histo_all_CMIP6&lon   = var_histo&lon
        delete( nyears )
        histo_all_CMIP6_masked= histo_all_CMIP6
      end if
      ;
      histo_all_CMIP6( models|m,{years|1995:2014},lat|:,lon|: ) = (/ var_histo /)
      ;
      ; Mask
      msk_conf         = conform( var_histo, msk, (/ 1,2 /) )
      var_histo_m      = where( msk_conf.ge.0.95, var_histo, var_histo@_FillValue )
      histo_all_CMIP6_masked( models|m,{years|1995:2014},lat|:,lon|: ) = (/ var_histo_m /)
      delete([/ msk_conf, var_histo, var_histo_m /])
      ;
      ;
      ; ########################
      ; ### SSP585
      ; ########################
      ;
      pathin           = pathin_root_CMIP6+"ssp585/"
      filein           = systemfunc( "ls "+pathin+index+"_ANN_climpact."+model+"_*" )
      ff               = addfile( filein, "r" )
      ;
      ti               = ff->time
      cal              = cd_calendar( ti, 0 )
      yrs              = cal( :,0 )
      i_fyr            = ind( yrs.eq.2080 )
      i_lyr            = ind( yrs.eq.2099 )
      delete([/ ti, cal, yrs /])
      ;
      var_ssp585       = ff->$(index)$( time|i_fyr:i_lyr,{lat|-45:-10},{lon|110:155} )
      delete([/ pathin, filein, ff, i_fyr, i_lyr /])
      ;
      if m.eq.0 then
        nyears         = 2099 - 2080 + 1
        ssp585_all_CMIP6       = new( (/ nmodels_ssp585, nyears, nlat, nlon /), float, histo_all_CMIP6@_FillValue )
        ssp585_all_CMIP6!0     = "models"
        ssp585_all_CMIP6!1     = "years"
        ssp585_all_CMIP6&years = ispan( 2080, 2099, 1 )
        ssp585_all_CMIP6!2     = "lat"
        ssp585_all_CMIP6&lat   = histo_all_CMIP6&lat
        ssp585_all_CMIP6!3     = "lon"
        ssp585_all_CMIP6&lon   = histo_all_CMIP6&lon
        delete( nyears )
        ssp585_all_CMIP6_masked= ssp585_all_CMIP6
      end if
      ;
      ssp585_all_CMIP6( models|m,{years|2080:2099},lat|:,lon|: ) = (/ var_ssp585 /)
      ;
      ; Mask
      msk_conf         = conform( var_ssp585, msk, (/ 1,2 /) )
      var_ssp585_m     = where( msk_conf.ge.0.95, var_ssp585, var_ssp585@_FillValue )
      ssp585_all_CMIP6_masked( models|m,{years|2080:2099},lat|:,lon|: ) = (/ var_ssp585_m /)
      delete([/ msk_conf, var_ssp585, var_ssp585_m /] )
      ;
      delete( model)
    end do ;  models ssp585
    ;
    ;
    ; Climatologies
    histo_all_CMIP5_clim  = dim_avg_n_Wrap(  histo_all_CMIP5, 1 )
    rcp85_all_CMIP5_clim  = dim_avg_n_Wrap(  rcp85_all_CMIP5, 1 )
    histo_all_CMIP6_clim  = dim_avg_n_Wrap(  histo_all_CMIP6, 1 )
    ssp585_all_CMIP6_clim = dim_avg_n_Wrap( ssp585_all_CMIP6, 1 )
    ;
    histo_all_CMIP5_masked_clim  = dim_avg_n_Wrap(  histo_all_CMIP5_masked, 1 )
    rcp85_all_CMIP5_masked_clim  = dim_avg_n_Wrap(  rcp85_all_CMIP5_masked, 1 )
    histo_all_CMIP6_masked_clim  = dim_avg_n_Wrap(  histo_all_CMIP6_masked, 1 )
    ssp585_all_CMIP6_masked_clim = dim_avg_n_Wrap( ssp585_all_CMIP6_masked, 1 )
    ;
    ; Calculate change and MMM
    change_CMIP5          =  rcp85_all_CMIP5_clim - histo_all_CMIP5_clim
    change_CMIP6          = ssp585_all_CMIP6_clim - histo_all_CMIP6_clim
    copy_VarMeta( histo_all_CMIP5_clim, change_CMIP5 )
    copy_VarMeta( histo_all_CMIP6_clim, change_CMIP6 )
    change_CMIP5_MMM      = dim_avg_n_Wrap( change_CMIP5, 0 )
    change_CMIP6_MMM      = dim_avg_n_Wrap( change_CMIP6, 0 )
    ;
    change_CMIP5_masked          =  rcp85_all_CMIP5_masked_clim - histo_all_CMIP5_masked_clim
    change_CMIP6_masked          = ssp585_all_CMIP6_masked_clim - histo_all_CMIP6_masked_clim
    copy_VarMeta( histo_all_CMIP5_masked_clim, change_CMIP5_masked )
    copy_VarMeta( histo_all_CMIP6_masked_clim, change_CMIP6_masked )
    change_CMIP5_masked_MMM      = dim_avg_n_Wrap( change_CMIP5_masked, 0 )
    change_CMIP6_masked_MMM      = dim_avg_n_Wrap( change_CMIP6_masked, 0 )
    delete([/ histo_all_CMIP5_clim, rcp85_all_CMIP5_clim, histo_all_CMIP6_clim, ssp585_all_CMIP6_clim, \
              histo_all_CMIP5_masked_clim, rcp85_all_CMIP5_masked_clim, \
              histo_all_CMIP6_masked_clim, ssp585_all_CMIP6_masked_clim,\
              change_CMIP5, change_CMIP6, change_CMIP5_masked, change_CMIP6_masked  /])
    ;
    ;
    ;
    ;
    ;
    ; ---------------------------------------------------------------------------------------------------------
    ;                  plot
    ; ---------------------------------------------------------------------------------------------------------
    ;
    ;
    if any( index.eq.(/ "tnn", "txx", "wsdi"/) ) then
      res@cnFillPalette  = "MPL_Reds" 
    else
      res@cnFillPalette  = "precip_diff_12lev" 
    end if
    ;
    print( "   "+min( (/ min( change_CMIP5_MMM ), min( change_CMIP6_MMM ) /) ) )
    print( "   "+max( (/ max( change_CMIP5_MMM ), max( change_CMIP6_MMM ) /) ) )
    if index.eq."tnn" then
      lname_index        = "TNn"
      res@cnLevelSelectionMode  = "ManualLevels"
      res@cnMinLevelValF =  2.5
      res@cnMaxLevelValF =  6.
      res@cnLevelSpacingF=  0.5
    end if
    if index.eq."rx1day" then
      delete([/ res@cnLevelSelectionMode, res@cnMinLevelValF, res@cnMaxLevelValF, res@cnLevelSpacingF /])
      lname_index        = "Rx1day"
      res@cnLevelSelectionMode = "ExplicitLevels"
      res@gsnSpreadColors = False
      res@cnLevels     := (/   -15, -10, -5, 0, 5, 10, 15, 20, 25, 30 /)
      res@cnFillColors := (/  0, 2,   4,  5, 7,  8, 9, 10, 11, 11, 12  /) 
    end if
    if index.eq."txx" then
      delete([/ res@cnLevelSelectionMode, res@gsnSpreadColors, res@cnLevels, res@cnFillColors /])
      lname_index        = "TXx"
      res@cnLevelSelectionMode  = "ManualLevels"
      res@cnMinLevelValF =  2.5
      res@cnMaxLevelValF =  6.
      res@cnLevelSpacingF=  0.5
    end if
    if index.eq."r10mm" then
      delete([/ res@cnLevelSelectionMode, res@cnMinLevelValF, res@cnMaxLevelValF, res@cnLevelSpacingF /])
      lname_index        = "R10mm"
      res@cnLevelSelectionMode = "ExplicitLevels"
      res@gsnSpreadColors = False
      res@cnLevels     := (/   -10, -5, -2, 0, 2,  5, 10, 15 /)
      res@cnFillColors := (/  0, 1,  3,  5, 7, 9, 10, 11, 12  /) 
    end if
    if index.eq."wsdi" then
      delete([/ res@cnLevelSelectionMode, res@gsnSpreadColors, res@cnLevels, res@cnFillColors /])
      lname_index        = "wsdi"
      res@cnLevelSelectionMode  = "ManualLevels"
      res@cnMinLevelValF =  40.
      res@cnMaxLevelValF =  340.
      res@cnLevelSpacingF=  60
    end if
    if index.eq."cdd" then
      delete([/ res@cnLevelSelectionMode, res@cnMinLevelValF, res@cnMaxLevelValF, res@cnLevelSpacingF /])
      lname_index        = "CDD"
      res@cnLevelSelectionMode = "ExplicitLevels"
      res@gsnSpreadColors = False
      res@cnLevels     := (/   -8, 0, 8, 16, 24, 32 /)
      res@cnFillColors := (/ 9, 7, 5, 3,  2,  1,  0 /) 
    end if
    ;
    ;
    ;
    res@gsnLeftString  = " "+lname_index+" ("+units+")"
    delete( lname_index )
    ;
    ; LEFT: CMIP5
    res@lbLabelBarOn   = True	
    res@lbBoxLinesOn   = True
    res@tmXBLabelsOn   = False
    res@tmYLLabelsOn   = True
    res@tmYRLabelsOn   = False
    res@gsnRightString= "CMIP5"
    plots( id )         = gsn_csm_contour_map( wks, change_CMIP5_MMM, res )
    ;
    ; RIGHT: CMIP6
    res@lbLabelBarOn   = False
    res@lbBoxLinesOn   = False
    res@tmXBLabelsOn   = True
    res@tmYLLabelsOn   = False
    res@tmYRLabelsOn   = True
    res@gsnLeftString  = " "
    res@gsnRightString= "CMIP6"
    plots_a( id )      = gsn_csm_contour_map( wks, change_CMIP6_MMM, res )
    ;
    ; Insert average over land
    weight             = NormCosWgtGlobe( change_CMIP5_MMM&lat )    
    change_CMIP5_MMM_avg = wgt_areaave_Wrap( change_CMIP5_masked_MMM, weight, 1., 0 )
    change_CMIP6_MMM_avg = wgt_areaave_Wrap( change_CMIP6_masked_MMM, weight, 1., 0 )
    ;
    ;
    attach             = gsn_attach_plots( plots( id ), plots_a( id ), res, res )
    ;
    delete([/ change_CMIP5_MMM, change_CMIP6_MMM, change_CMIP5_masked_MMM, change_CMIP6_masked_MMM, \
              change_CMIP5_MMM_avg, change_CMIP6_MMM_avg /])
    ;
    delete( index )
  end do ; indices
  ;
  ;
  ; letters / panels
  txtres                 = True
  txtres@txBackgroundFillColor = "white"
  txtres@txPerimOn       = True
  txtres@txPerimThicknessF = 1
  txtres@txPerimColor    = 1
  txtres@txFontHeightF   = 0.025
  amres                  = True
  amres@amParallelPosF   =  -0.45    ; This is the left edge of the plot.
  amres@amOrthogonalPosF =  -0.42
  dumtext_a          = gsn_create_text( wks, "a", txtres )
  dumtext_b          = gsn_create_text( wks, "b", txtres )
  dumtext_c          = gsn_create_text( wks, "c", txtres )
  dumtext_d          = gsn_create_text( wks, "d", txtres )
  dumtext_e          = gsn_create_text( wks, "e", txtres )
  dumtext_f          = gsn_create_text( wks, "f", txtres )
  annoid_a           = gsn_add_annotation( plots( 0  ), dumtext_a, amres )
  annoid_b           = gsn_add_annotation( plots( 1  ), dumtext_b, amres )
  annoid_c           = gsn_add_annotation( plots( 2  ), dumtext_c, amres )
  annoid_d           = gsn_add_annotation( plots( 3  ), dumtext_d, amres )
  annoid_e           = gsn_add_annotation( plots( 4  ), dumtext_e, amres )
  annoid_f           = gsn_add_annotation( plots( 5  ), dumtext_f, amres )
  ;
  ;
  pres               = True
  pres@gsnFrame      = False
  pres@txString      = "difference maps for indices of temperature and precipitation extremes"
  pres@txFontHeightF = 0.015
  gsn_panel( wks, plots, (/3,2/), pres )
  ;
  frame( wks )
  ;
  system( "display "+pathoutfig+namefig+"."+qual+" &" )
  ;
  ;
  ;
end
;EOF

