; Margot Bador, UNSW, m.bador@unsw.edu.au, 2020.
;
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"

begin
  ;
  ;
;########### Miscellaneous ##############################################"
  ; 
  indices            = (/ "tnn", "rx1day", "txx", "r10mm", "wsdi", "cdd" /)
  ;
  pathoutfig         = "/g/data/w40/mba561/figures/ncl/first_look_at_CMIP6_Australia/"
  namefig            = "Supp_Figure_1"
  ;
  ;
;#######################################################################"
  ;
  ;
  nindices           = dimsizes( indices )
  ;
  ; Prep loading the indice of every datasets
  pathin             = "/g/data/w40/mba561/AWAP_regridded/"
  ;
  ;
  ;
  ;
  ;
  ; ---------------------------------------------------------------------------------------------------------
  ;                  Prepare plot
  ; ---------------------------------------------------------------------------------------------------------
  ;
  ;
  ; Prep the  plot
  qual               = "png" ; png ps
  wks                = gsn_open_wks( qual, pathoutfig+namefig )
  plots              = new( 6, graphic )
  dumtext            = new( 6, graphic )
  annoid             = new( 6, graphic )
  ;
  res               = True  
  res@gsnDraw       = False
  res@gsnFrame      = False
  res@gsnAddCyclic  = False
  res@cnFillOn      = True
  res@cnLinesOn     = False
  res@cnLineLabelsOn= False
  ;
  res@gsnStringFontHeightF = 0.03
  res@lbLabelFontHeightF   = 0.03
  ;
  ; raster
  res@cnFillMode     = "RasterFill"
  res@mpOceanFillColor = "gray92" 
  res@mpLandFillColor  = "gray92" 
  res@mpFillDrawOrder  = "PreDraw"
  res@mpFillColors   = (/ -1,0,-1,-1 /)
  ; plot in a box 
  res@mpMinLatF      = -45
  res@mpMaxLatF      = -10
  res@mpMinLonF      = 110
  res@mpMaxLonF      = 155
  ;
  ;
  ;
  ; ---------------------------------------------------------------------------------------------------------
  ;                  For each index
  ; ---------------------------------------------------------------------------------------------------------
  ;
  do id              = 0, nindices - 1
    ;
    index            = indices( id )
    print(" ")
    print(" ")
    print(" --------------- ")
    print(" "+index)
    ;
    ;
    filein           = index+"ANN_climpact_AWAP_regridded_and_masked.nc"
    ff               = addfile( pathin+filein, "r" )
    ;
    ti               = ff->time
    cal              = cd_calendar( ti, 0 )
    yrs              = cal( :,0 )
    i_fyr            = ind( yrs.eq.1995 )
    i_lyr            = ind( yrs.eq.2014 )
    delete([/ ti, cal, yrs /])
    ;
    var              = ff->$index$( time|i_fyr:i_lyr,{lat|-45:-10},{lon|110:155} )
    delete([/ filein, ff, i_fyr, i_lyr /])
    ;
    units            = var@units
    print(" "+units)
    if units.eq."degrees_C" then
      units               := "~S~o~N~C"
    end if
    ;
    ;
    ; Climatology
    var_clim         = dim_avg_n_Wrap( var, 0 )
    delete( var )
    ;
    ;
    ;
    ;
    ; ---------------------------------------------------------------------------------------------------------
    ;                  plot
    ; ---------------------------------------------------------------------------------------------------------
    ;
    ;
    if any( index.eq.(/ "tnn", "txx", "wsdi"/) ) then
      res@cnFillPalette  = "amwg256" 
    else
      res@cnFillPalette  = "GMT_drywet"
    end if
    ;
    if index.eq."tnn" then
      lname_index        = "TNn"
      res@cnLevelSelectionMode  = "ManualLevels"
      res@cnMinLevelValF =  -14.
      res@cnMaxLevelValF =  14.
      res@cnLevelSpacingF=  2.0
    end if
    if index.eq."rx1day" then
      delete([/ res@cnLevelSelectionMode, res@cnMinLevelValF, res@cnMaxLevelValF, res@cnLevelSpacingF /])
      lname_index        = "Rx1day"
    end if
    if index.eq."txx" then
      lname_index        = "TXx"
      res@gsnSpreadColors = True
      res@gsnSpreadColorStart = 127
      res@gsnSpreadColorEnd   = 252
    end if
    if index.eq."r10mm" then
      lname_index        = "R10mm"
      delete([/ res@gsnSpreadColors, res@gsnSpreadColorStart, res@gsnSpreadColorEnd /])
    end if
    if index.eq."wsdi" then
      lname_index        = "wsdi"
      res@gsnSpreadColors = True
      res@gsnSpreadColorStart = 127
      res@gsnSpreadColorEnd   = 252
    end if
    if index.eq."cdd" then
      delete([/ res@gsnSpreadColors, res@gsnSpreadColorStart, res@gsnSpreadColorEnd /])
      lname_index        = "CDD"
      res@gsnSpreadColors = True
      res@gsnSpreadColorStart = 59
      res@gsnSpreadColorEnd   = 0
    end if
    ;
    ;
    ;
    res@gsnLeftString  = " "+lname_index+" ("+units+")"
    res@gsnRightString = " "
    delete( lname_index )
    ;
    plots( id )        = gsn_csm_contour_map( wks, var_clim, res )
    ;
    ; Insert average over land
    weight             = NormCosWgtGlobe(  var_clim&lat )    
    var_clim_mean      = wgt_areaave_Wrap( var_clim, weight, 1., 0 )
    ;
    delete([/ var_clim_mean, var_clim, units /])
    ;
    delete( index )
  end do ; indices
  ;
  ;
  ; letters / panels
  txtres                 = True
  txtres@txBackgroundFillColor = "white"
  txtres@txPerimOn       = True
  txtres@txPerimThicknessF = 1
  txtres@txPerimColor    = 1
  txtres@txFontHeightF   = 0.025
  amres                  = True
  amres@amParallelPosF   =  -0.45    ; This is the left edge of the plot.
  amres@amOrthogonalPosF =  -0.42
  dumtext_a          = gsn_create_text( wks, "a", txtres )
  dumtext_b          = gsn_create_text( wks, "b", txtres )
  dumtext_c          = gsn_create_text( wks, "c", txtres )
  dumtext_d          = gsn_create_text( wks, "d", txtres )
  dumtext_e          = gsn_create_text( wks, "e", txtres )
  dumtext_f          = gsn_create_text( wks, "f", txtres )
  annoid_a           = gsn_add_annotation( plots( 0  ), dumtext_a, amres )
  annoid_b           = gsn_add_annotation( plots( 1  ), dumtext_b, amres )
  annoid_c           = gsn_add_annotation( plots( 2  ), dumtext_c, amres )
  annoid_d           = gsn_add_annotation( plots( 3  ), dumtext_d, amres )
  annoid_e           = gsn_add_annotation( plots( 4  ), dumtext_e, amres )
  annoid_f           = gsn_add_annotation( plots( 5  ), dumtext_f, amres )
  ;
  ;
  pres               = True
  pres@gsnFrame      = False
  pres@txFontHeightF = 0.015
  gsn_panel( wks, plots, (/3,2/), pres )
  ;
  frame( wks )
  ;
  system( "display "+pathoutfig+namefig+"."+qual+" &" )
  ;
  ;
  ;
end
;EOF
