; Margot Bador, UNSW, m.bador@unsw.edu.au, 2020.
;
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"

begin
  ;
  ;
;########### Miscellaneous ##############################################"
  ; 
  indices            = (/ "tnn", "rx1day", "txx", "r10mm", "wsdi", "cdd" /)
  ;
  pathoutfig         = "/g/data/w40/mba561/figures/ncl/first_look_at_CMIP6_Australia/"
  namefig            = "Supp_Figure_2"
  ;
  ;
;#######################################################################"
  ;
  ;                     
  ; ## Load model name list
  li_histo_CMIP5     = "list_models_historical_for_indices_CMIP5.txt"
  models_histo_CMIP5 = asciiread( li_histo_CMIP5,-1,"string" )
  nmodels_histo_CMIP5= dimsizes( models_histo_CMIP5 )
  li_histo_CMIP6     = "list_models_historical_for_indices_CMIP6.txt"
  models_histo_CMIP6 = asciiread( li_histo_CMIP6,-1,"string" )
  nmodels_histo_CMIP6= dimsizes( models_histo_CMIP6 )
  li_rcp85           = "list_models_rcp85_for_indices_CMIP5.txt"
  models_rcp85       = asciiread( li_rcp85,-1,"string" )
  nmodels_rcp85      = dimsizes( models_rcp85 )
  li_ssp585          = "list_models_ssp585_for_indices_CMIP6.txt"
  models_ssp585      = asciiread( li_ssp585,-1,"string" )
  nmodels_ssp585     = dimsizes( models_ssp585 )
  ;
  ;              
  ; Prep loading the indice of every datasets
  pathin_awap        = "/g/data/w40/mba561/AWAP_regridded/"
  pathin_root_CMIP5  = "/g/data/w40/mba561/cmip_regridded/CMIP5/"
  pathin_root_CMIP6  = "/g/data/w40/mba561/cmip_regridded/CMIP6/"
  ;
  ;
  ;
  ; ## Define years
  years_CMIP5        = ispan( 1961, 2014, 1 )
  nyears_CMIP5       = dimsizes( years_CMIP5 )
  years_CMIP6        = ispan( 1950, 2014, 1 )
  nyears_CMIP6       = dimsizes( years_CMIP6 )
  years_awap         = ispan( 1950, 2018, 1 )
  ;
  ;
  ; ## Load AWAP's mask
  pathin_awap        = "/g/data/w40/mba561/AWAP_regridded/"
  filein_mask        = "mask_AWAP_r240.120.nc"
  ff                 = addfile( pathin_awap+filein_mask, "r" )
  awap_msk           = ff->variable( time|0,{lat|-45:-10},{lon|112.5:155} ) 
  ;
  ;
  ;
  ; ---------------------------------------------------------------------------------------------------------
  ;                  Prepare plot
  ; ---------------------------------------------------------------------------------------------------------
  ;
  ;
  ; Prep the  plot
  qual               = "png" ; png ps
  wks                = gsn_open_wks( qual, pathoutfig+namefig )
  gsn_define_colormap( wks, "cosam" )
  plots              = new( 6, graphic )
  plot_mmm_CMIP5     = new( 6, graphic )
  plot_mmm_CMIP6_for_ssp585 = new( 6, graphic )
  plot_mmm_CMIP6_histo_only = new( 6, graphic )
  plot_awap_mean            = new( 6, graphic )
  shading_CMIP5             = new( 6, graphic )
  shading_CMIP6_histo_only  = new( 6, graphic )
  shading_CMIP6_for_ssp585  = new( 6, graphic )
  ;
  ;
  ; Ressources for zonal mean
  res                = True  
  res@gsnDraw        = False
  res@gsnFrame       = False
  res@xyMonoDashPattern = True
  ;
  res@vpHeightF      = 0.8
  res@vpWidthF       = 1.2
  ;
  res@tiYAxisFontHeightF   = 0.04
  res@tmYLLabelFontHeightF = 0.04
  res@gsnStringFontHeightF = 0.04
  res@gsnLeftStringFontHeightF = 0.05
  ;
  ;
  res@tfPolyDrawOrder    = "Predraw"               ; put line on top 
  ;
  ; ressource for polygon / shading
  gsres                   = True   
  gsres@gsFillOpacityF    = 0.2
  dbl_x_CMIP5             = array_append_record( years_CMIP5, years_CMIP5(::-1), 0 )
  dbl_x_CMIP6             = array_append_record( years_CMIP6, years_CMIP6(::-1), 0 )
  ;
  res@trXMinF        = 1950
  res@trXMaxF        = 2014
  ;
  ;
  ;
  ; ---------------------------------------------------------------------------------------------------------
  ;                  For each index
  ; ---------------------------------------------------------------------------------------------------------
  ;
  nindices           = dimsizes( indices )
  do id              = 0, nindices - 1
    ;
    index            = indices( id )
    print(" ")
    print(" ")
    print(" --------------- ")
    print(" ---- "+index)
    print(" ")
    ;
    ;
    ;
    filein           = index+"ANN_climpact_AWAP_regridded_and_masked.nc"
    ff               = addfile( pathin_awap+filein, "r" )
    ;
    ti               = ff->time
    cal              = cd_calendar( ti, 0 )
    yrs              = cal( :,0 )
    i_fyr            = ind( yrs.eq.1950 )
    i_lyr            = ind( yrs.eq.2018 )
    delete([/ ti, cal, yrs /])
    ;
    var              = ff->$index$( time|i_fyr:i_lyr,{lat|-45:-10},{lon|110:155} ) 
    delete([/ filein, ff, i_fyr, i_lyr /])
    ;
    ; Spatial mean
    weights          = NormCosWgtGlobe( var&lat )
    awap_mean        = wgt_areaave_Wrap( var, weights, 1., 0 )
    delete([/ var, weights /])
    ;
    ;
    ; ---------------------------------------------------------------------------------------------------------
    ;                  CMIP5 - rcp85 // 
    ; ---------------------------------------------------------------------------------------------------------
    ;
    print(" CMIP5 ")
    ;
    ; Loop through datasets  
    do m               = 0, nmodels_rcp85 - 1
      ;
      model            = models_rcp85( m )
      ;
      ; ########################
      ; ### Historical
      ; ########################
      ;
      pathin           = pathin_root_CMIP5+"historical/"
      filein           = systemfunc( "ls "+pathin+index+"ETCCDI_yr_"+model+"_*" )
      ff               = addfile( filein, "r" )
      var              = ff->$(index+"ETCCDI")$( time|:,{lat|-45:-10},{lon|112.5:155} )
      delete([/ filein, ff /])
      cal              = cd_calendar( var&time, 0 )
      years            = cal( :,0 )
      delete( cal )
      ;
      if m.eq.0 then
        nyears         = 2005 - 1961 + 1
        histo_all_CMIP5= new( (/ nmodels_rcp85, nyears /), float, var@_FillValue )
        histo_all_CMIP5!0 = "models"
        units          = var@units
        delete( nyears )
        if units.eq."degrees_C" then
          units               := "~S~o~N~C"
        end if
      end if
      ;
      weights          = NormCosWgtGlobe( var&lat )
      ii_years         = ind( years.ge.1961 .and. years.le.2005 )
      sel              = var( time|ii_years,lat|:,lon|: )
      ;
      ; Mask
      msk_conf         = conform( sel, awap_msk, (/ 1,2 /) )
      sel              = where( msk_conf.eq.1.0, sel, sel@_FillValue )
      delete( msk_conf )
      ;
      histo_all_CMIP5( m,: ) = wgt_areaave_Wrap( sel, weights, 1., 0 )
      delete([/ years, ii_years, sel, var /])
      ;
      ;
      ; ########################
      ; ### RCP8.5
      ; ########################
      ;
      pathin           = pathin_root_CMIP5+"rcp85/"
      filein           = systemfunc( "ls "+pathin+index+"ETCCDI_yr_"+model+"_*" )
      ff               = addfile( filein, "r" )
      var              = ff->$(index+"ETCCDI")$( time|:,{lat|-45:-10},{lon|112.5:155} )
      delete([/ pathin,filein, ff /])
      cal              = cd_calendar( var&time, 0 )
      years            = cal( :,0 )
      delete( cal )
      ;
      if m.eq.0 then
        nyears         = 2014 - 2006 + 1
        rcp85_all      = new( (/ nmodels_rcp85, nyears /), float, var@_FillValue )
        rcp85_all!0    = "models"
        delete( nyears )
      end if
      ;
      ii_years         = ind( years.ge.2006 .and. years.le.2014 )
      sel              = var( time|ii_years,lat|:,lon|: )
      ;
      ; Mask
      msk_conf         = conform( sel, awap_msk, (/ 1,2 /) )
      sel              = where( msk_conf.eq.1.0, sel, sel@_FillValue )
      delete( msk_conf )
      ;
      rcp85_all( m,: ) = wgt_areaave_Wrap( sel, weights, 1., 0 )
      delete([/ years, ii_years, sel, var /])
      ;
      delete([/ model, weights /])
    end do ;  models rcp85
    ;
    ;
    ;
    ;
    ;
    ; ---------------------------------------------------------------------------------------------------------
    ;                  CMIP6 - ssp585
    ; ---------------------------------------------------------------------------------------------------------
    ;
    print(" CMIP6 ")
    print("   all available historical")
    ;
    ; Loop through datasets  
    do m               = 0, nmodels_histo_CMIP6 - 1
      ;
      model            = models_histo_CMIP6( m )
      ;
      pathin           = pathin_root_CMIP6+"historical/"
      filein           = systemfunc( "ls "+pathin+index+"_ANN_climpact."+model+"_*" )
      ;
      ff               = addfile( filein, "r" )
      var              = ff->$index$( time|:,{lat|-45:-10},{lon|112.5:155} )
      delete([/ pathin, filein, ff /])
      cal              = cd_calendar( var&time, 0 )
      years            = cal( :,0 )
      delete( cal )
      ;
      if m.eq.0 then
        nyears         = 2014 - 1950 + 1
        CMIP6_histo_only_all      = new( (/ nmodels_histo_CMIP6, nyears /), float, var@_FillValue )
        CMIP6_histo_only_all!0 = "models"
        delete( nyears )
      end if
      ;
      weights          = NormCosWgtGlobe( var&lat )
      ii_years         = ind( years.ge.1950 .and. years.le.2014 )
      sel              = var( time|ii_years,lat|:,lon|: )
      ;
      ; Mask
      msk_conf         = conform( sel, awap_msk, (/ 1,2 /) )
      sel              = where( msk_conf.eq.1.0, sel, sel@_FillValue )
      delete( msk_conf )
      ;
      CMIP6_histo_only_all( m,: ) = wgt_areaave_Wrap( sel, weights, 1., 0 )
      delete([/ years, ii_years, sel, var /])
      ;
      ;
      delete([/ model, weights /])
    end do ;  models ssp585
    ;
    ;
    print("   historical for ssp585")
    ;
    ; Loop through datasets  
    do m               = 0, nmodels_ssp585 - 1
      ;
      model            = models_ssp585( m )
      ;
      pathin           = pathin_root_CMIP6+"historical/"
      filein           = systemfunc( "ls "+pathin+index+"_ANN_climpact."+model+"_*" )
      ff               = addfile( filein, "r" )
      var              = ff->$index$( time|:,{lat|-45:-10},{lon|112.5:155} )
      delete([/ pathin, filein, ff /])
      cal              = cd_calendar( var&time, 0 )
      years            = cal( :,0 )
      delete( cal )
      ;
      if m.eq.0 then
        nyears         = 2014 - 1950 + 1
        CMIP6_for_ssp585_all      = new( (/ nmodels_ssp585, nyears /), float, var@_FillValue )
        CMIP6_for_ssp585_all!0 = "models"
        delete( nyears )
      end if
      ;
      weights          = NormCosWgtGlobe( var&lat )
      ii_years         = ind( years.ge.1950 .and. years.le.2014 )
      sel              = var( time|ii_years,lat|:,lon|: )
      ;
      ; Mask
      msk_conf         = conform( sel, awap_msk, (/ 1,2 /) )
      sel              = where( msk_conf.eq.1.0, sel, sel@_FillValue )
      delete( msk_conf )
      ;
      CMIP6_for_ssp585_all( m,: ) = wgt_areaave_Wrap( sel, weights, 1., 0 )
      delete([/ years, ii_years, sel, var /])
      ;
      ;
      delete([/ model, weights /])
    end do ;  models ssp585
    ;
    ;
    ;
    ; ---------------------------------------------------------------------------------------------------------
    ;                  Work on data
    ; ---------------------------------------------------------------------------------------------------------
    ;
    ;
    ; Concatene historical and future experiments for CMIP5
    ; CMIP5
    CMIP5_all          = new( (/ nmodels_rcp85,  nyears_CMIP5 /),float , histo_all_CMIP5@_FillValue )
    CMIP5_all!0        = "models"
    do mo              = 0, nmodels_rcp85 - 1
      CMIP5_all( mo,: )= array_append_record( histo_all_CMIP5( mo,: ), rcp85_all( mo,: ), 0 )
    end do  
    ;
    ;
    ;
    ;
    ; ---------------------------------------------------------------------------------------------------------
    ;                  plot
    ; ---------------------------------------------------------------------------------------------------------
    ;
    if index.eq."wsdi" then
      res@tmYLPrecision= 3	
    end if
    if index.eq."txx" .or. index.eq."r10mm" then
      res@tmYLPrecision= 2	
    end if
    ;
    if index.eq."tnn" then
      lname_index        = "TNn"
    end if
    if index.eq."rx1day" then
      lname_index        = "Rx1day"
    end if
    if index.eq."txx" then
      lname_index        = "TXx"
    end if
    if index.eq."r10mm" then
      lname_index        = "R10mm"
    end if
    if index.eq."wsdi" then
      lname_index        = "wsdi"
    end if
    if index.eq."cdd" then
      lname_index        = "CDD"
    end if
    ;
    res@trYMinF        = min( (/ min( CMIP5_all ), min( CMIP6_histo_only_all ) /) )
    res@trYMaxF        = max( (/ max( CMIP5_all ), max( CMIP6_histo_only_all ) /) )
    ;
    res@tiYAxisString  = " "+units
    res@gsnLeftString  = " "+lname_index
    delete( lname_index )
    ;
    ; 1. Dum plot before shadings
    res@xyLineColor     = "white"
    plots( id )         = gsn_csm_xy( wks, years_CMIP5, CMIP5_all( 0,: ) + 1000., res )
    res@gsnLeftString   = " "
    res@gsnRightString  = " "
    ;
    res@xyLineThicknessF= 5.
    res@xyLineColor     = "gray30"
    plot_mmm_CMIP5( id )      = gsn_csm_xy( wks, years_CMIP5, dim_avg_n_Wrap( CMIP5_all, 0 ), res )
    res@xyLineColor     = "gold"
    plot_mmm_CMIP6_histo_only( id ) = gsn_csm_xy( wks, years_CMIP6, dim_avg_n_Wrap( CMIP6_histo_only_all, 0 ), res )
    res@xyLineColor     = "red"
    plot_mmm_CMIP6_for_ssp585( id ) = gsn_csm_xy( wks, years_CMIP6, dim_avg_n_Wrap( CMIP6_for_ssp585_all, 0 ), res )
    res@xyLineColor     = "black"
    plot_awap_mean( id )= gsn_csm_xy( wks, years_awap, awap_mean, res )
    ;
    gsres@gsFillColor   = "gray40"
    mi                  := dim_min_n_Wrap( CMIP5_all, 0 )                                      
    ma                  := dim_max_n_Wrap( CMIP5_all, 0 )
    y_sha               := array_append_record( mi, ma(::-1) ,0)                                      
    shading_CMIP5( id )       = gsn_add_polygon( wks, plots( id ), dbl_x_CMIP5, y_sha, gsres )
    gsres@gsFillColor   = "gold"
    mi                  := dim_min_n_Wrap( CMIP6_histo_only_all, 0 )                                      
    ma                  := dim_max_n_Wrap( CMIP6_histo_only_all, 0 )
    y_sha               := array_append_record( mi, ma(::-1) ,0)                                      
    shading_CMIP6_histo_only( id )  = gsn_add_polygon( wks, plots( id ), dbl_x_CMIP6, y_sha, gsres )
    gsres@gsFillColor   = "red"
    mi                  := dim_min_n_Wrap( CMIP6_for_ssp585_all, 0 )                                      
    ma                  := dim_max_n_Wrap( CMIP6_for_ssp585_all, 0 )
    y_sha               := array_append_record( mi, ma(::-1) ,0)                                      
    shading_CMIP6_for_ssp585( id )  = gsn_add_polygon( wks, plots( id ), dbl_x_CMIP6, y_sha, gsres )
    ;
    overlay( plots( id ), plot_mmm_CMIP5( id ) )
    overlay( plots( id ), plot_mmm_CMIP6_for_ssp585( id ) )
    overlay( plots( id ), plot_mmm_CMIP6_histo_only( id ) )
    overlay( plots( id ), plot_awap_mean( id ) )
    ;
    ;
    delete([/ index, awap_mean /])
  end do ; indices
  ;
  ;
  ;
  ;************************************************
  ; letters / panels
  ;************************************************
  txtres                 = True
  txtres@txPerimOn       = True
  txtres@txPerimThicknessF = 1
  txtres@txPerimColor    = 1
  txtres@txFontHeightF   = 0.04
  amres                  = True
  amres@amParallelPosF   = -0.47   
  amres@amOrthogonalPosF = -0.45
  dumtext_a          = gsn_create_text( wks, "a", txtres )
  dumtext_b          = gsn_create_text( wks, "b", txtres )
  dumtext_c          = gsn_create_text( wks, "c", txtres )
  dumtext_d          = gsn_create_text( wks, "d", txtres )
  dumtext_e          = gsn_create_text( wks, "e", txtres )
  dumtext_f          = gsn_create_text( wks, "f", txtres )
  annoid_a           = gsn_add_annotation( plots( 0  ), dumtext_a, amres )
  annoid_b           = gsn_add_annotation( plots( 1  ), dumtext_b, amres )
  annoid_c           = gsn_add_annotation( plots( 2  ), dumtext_c, amres )
  annoid_d           = gsn_add_annotation( plots( 3  ), dumtext_d, amres )
  annoid_e           = gsn_add_annotation( plots( 4  ), dumtext_e, amres )
  annoid_f           = gsn_add_annotation( plots( 5  ), dumtext_f, amres )
  ;
  ;
  ;
  ;
  pres               = True
  pres@gsnFrame      = False
  gsn_panel( wks, plots, (/3,2/), pres )
  ;
  frame( wks )
  ;
  system( "display "+pathoutfig+namefig+"."+qual+" &" )

  ;
  ;
end
;EOF
