; Margot Bador, UNSW, m.bador@unsw.edu.au, 2020.
;
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"

begin
  ;
  ;
;########### Miscellaneous ##############################################"
  ; 
  indices            = (/ "tnn", "rx1day", "txx", "r10mm", "wsdi", "cdd" /)
  ;
  pathoutfig         = "/g/data/w40/mba561/figures/ncl/first_look_at_CMIP6_Australia/"
  namefig            = "Supp_Figure_3"
  ;
  ;
;#######################################################################"
  ;
  ;
  nindices           = dimsizes( indices )
  ;                     
  ; ## Load model name list
  li_rcp85           = "list_models_rcp85_for_indices_CMIP5.txt"
  models_rcp85       = asciiread( li_rcp85,-1,"string" )
  nmodels_rcp85      = dimsizes( models_rcp85 )
  li_ssp585          = "list_models_ssp585_for_indices_CMIP6.txt"
  models_ssp585      = asciiread( li_ssp585,-1,"string" )
  nmodels_ssp585     = dimsizes( models_ssp585 )
  ;
  ;              
  ; Prep loading the indice of every datasets
  pathin_awap        = "/g/data/w40/mba561/AWAP_regridded/"
  pathin_root_CMIP5  = "/g/data/w40/mba561/cmip_regridded/CMIP5/"
  pathin_root_CMIP6  = "/g/data/w40/mba561/cmip_regridded/CMIP6/"
  ;
  ;
  ;
  ;
  ;
  ;
  ; ---------------------------------------------------------------------------------------------------------
  ;                  Prepare plot
  ; ---------------------------------------------------------------------------------------------------------
  ;
  ;
  ; Prep the  plot
  qual               = "png" ; png ps
  wks                = gsn_open_wks( qual, pathoutfig+namefig )
  plots              = new( 6, graphic )
  plots_a            = new( 6, graphic )
  dumtext_0          = new( 6, graphic )
  dumtext_1          = new( 6, graphic )
  annoid_0           = new( 6, graphic )
  annoid_1           = new( 6, graphic )
  ;
  res               = True  
  res@gsnDraw       = False
  res@gsnFrame      = False
  res@gsnAddCyclic  = False
  res@cnFillOn      = True
  res@cnLinesOn     = False
  res@cnLineLabelsOn= False
  ;
  res@gsnStringFontHeightF = 0.03
  res@lbLabelFontHeightF   = 0.03
  res@tmXBLabelFontHeightF = 0.025
  res@tmXTLabelFontHeightF = 0.025
  res@tmYLLabelFontHeightF = 0.025
  res@tmYRLabelFontHeightF = 0.025
  ;
  ; raster
  res@cnFillMode     = "RasterFill"
  res@mpOceanFillColor = "gray92" ; "lightcyan"
  res@mpLandFillColor  = "gray92" ; "lightcyan"
  res@mpFillDrawOrder  = "PreDraw"
  res@mpFillColors   = (/ -1,0,-1,-1  /)
  ; plot in a box 
  res@mpMinLatF      = -45
  res@mpMaxLatF      = -10
  res@mpMinLonF      = 110
  res@mpMaxLonF      = 155
  ;
  ;
  ;
  ; ---------------------------------------------------------------------------------------------------------
  ;                  For each index
  ; ---------------------------------------------------------------------------------------------------------
  ;
  do id              = 0, nindices - 1
    ;
    index            = indices( id )
    print(" ")
    print(" ")
    print(" --------------- ")
    print(" "+index)
    ;
    ;
    ;
    filein           = index+"ANN_climpact_AWAP_regridded_and_masked.nc"
    ff               = addfile( pathin_awap+filein, "r" )
    ;
    ti               = ff->time
    cal              = cd_calendar( ti, 0 )
    yrs              = cal( :,0 )
    i_fyr            = ind( yrs.eq.1995 )
    i_lyr            = ind( yrs.eq.2014 )
    delete([/ ti, cal, yrs /])
    ;
    var              = ff->$index$( time|i_fyr:i_lyr,{lat|-45:-10},{lon|110:155} ) 
    delete([/ filein, ff, i_fyr, i_lyr /])
    ;
    ; Climatology
    awap_clim         = dim_avg_n_Wrap( var, 0 )
    delete( var )
    ;
    ; ---------------------------------------------------------------------------------------------------------
    ;
    ;
    ;                  CMIP5 - rcp85
    ; ---------------------------------------------------------------------------------------------------------
    ;
    ; Loop through datasets  
    do m               = 0, nmodels_rcp85 - 1
      ;
      model            = models_rcp85( m )
      ;
      ; ########################
      ; ### Historical
      ; ########################
      ;
      pathin           = pathin_root_CMIP5+"historical/"
      filein           = systemfunc( "ls "+pathin+index+"ETCCDI_yr_"+model+"_*" )
      ff               = addfile( filein, "r" )
      ;
      ti               = ff->time
      cal              = cd_calendar( ti, 0 )
      yrs              = cal( :,0 )
      i_fyr            = ind( yrs.eq.1995 )
      i_lyr            = ind( yrs.eq.2005 )
      delete([/ ti, cal, yrs /])
      ;
      var_histo_part1  = ff->$(index+"ETCCDI")$( time|i_fyr:i_lyr,{lat|-45:-10},{lon|112.5:155} )
      delete([/ pathin, filein, ff, i_fyr, i_lyr /])
      ;
      if m.eq.0 then
        nyears         = 2014 - 1995 + 1
        nlat           = dimsizes( var_histo_part1&lat )
        nlon           = dimsizes( var_histo_part1&lon )
        histo_all_CMIP5       = new( (/ nmodels_rcp85, nyears, nlat, nlon /), float, var_histo_part1@_FillValue )
        histo_all_CMIP5!0     = "models"
        histo_all_CMIP5!1     = "years"
        histo_all_CMIP5&years = ispan( 1995, 2014, 1 )
        histo_all_CMIP5!2     = "lat"
        histo_all_CMIP5&lat   = var_histo_part1&lat
        histo_all_CMIP5!3     = "lon"
        histo_all_CMIP5&lon   = var_histo_part1&lon
        units                 = var_histo_part1@units
        if units.eq."degrees_C" then
          units               := "~S~o~N~C"
        end if
        delete( nyears )
      end if
      ;
      histo_all_CMIP5( models|m,{years|1995:2005},lat|:,lon|: ) = (/ var_histo_part1 /)
      delete( var_histo_part1 )
      ;
      ;
      ; ########################
      ; ### RCP8.5
      ; ########################
      ;
      pathin           = pathin_root_CMIP5+"rcp85/"
      filein           = systemfunc( "ls "+pathin+index+"ETCCDI_yr_"+model+"_*" )
      ff               = addfile( filein, "r" )
      ;
      ti               = ff->time
      cal              = cd_calendar( ti, 0 )
      yrs              = cal( :,0 )
      i_fyr            = ind( yrs.eq.2006 )
      i_lyr            = ind( yrs.eq.2014 )
      delete([/ ti, cal, yrs /])
      ;
      var_histo_part2  = ff->$(index+"ETCCDI")$( time|i_fyr:i_lyr,{lat|-45:-10},{lon|112.5:155} )
      delete([/ i_fyr, i_lyr /])
      ;
      histo_all_CMIP5( models|m,{years|2006:2014},lat|:,lon|: ) = (/ var_histo_part2 /)
      delete( var_histo_part2 )
      ;
      delete( model )
    end do ;  models rcp85
    ;
    ;
    ;
    ;
    ; ---------------------------------------------------------------------------------------------------------
    ;                  CMIP6 - ssp585
    ; ---------------------------------------------------------------------------------------------------------
    ;
    ;
    ; Loop through datasets  
    do m               = 0, nmodels_ssp585 - 1
      ;
      model            = models_ssp585( m )
      ;
      ; ########################
      ; ### Historical
      ; ########################
      ;
      pathin           = pathin_root_CMIP6+"historical/"
      filein           = systemfunc( "ls "+pathin+index+"_ANN_climpact."+model+"_*" )
      ff               = addfile( filein, "r" )
      ti               = ff->time
      cal              = cd_calendar( ti, 0 )
      yrs              = cal( :,0 )
      i_fyr            = ind( yrs.eq.1995 )
      i_lyr            = ind( yrs.eq.2014 )
      delete([/ ti, cal, yrs /])
      ;
      var_histo        = ff->$index$( time|i_fyr:i_lyr,{lat|-45:-10},{lon|112.5:155} )
      delete([/ pathin, filein, ff, i_fyr, i_lyr /])
      ;
      if m.eq.0 then
        nyears         = 2014 - 1995 + 1
        nlat           = dimsizes( var_histo&lat )
        nlon           = dimsizes( var_histo&lon )
        histo_all_CMIP6       = new( (/ nmodels_ssp585, nyears, nlat, nlon /), float, var_histo@_FillValue )
        histo_all_CMIP6!0     = "models"
        histo_all_CMIP6!1     = "years"
        histo_all_CMIP6&years = ispan( 1995, 2014, 1 )
        histo_all_CMIP6!2     = "lat"
        histo_all_CMIP6&lat   = var_histo&lat
        histo_all_CMIP6!3     = "lon"
        histo_all_CMIP6&lon   = var_histo&lon
        delete( nyears )
      end if
      ;
      histo_all_CMIP6( models|m,{years|1995:2014},lat|:,lon|: ) = (/ var_histo /)
      delete( var_histo )
      ;
      delete( model)
    end do ;  models ssp585
    ;
    ;
    ; Climatologies
    histo_all_CMIP5_clim  = dim_avg_n_Wrap(  histo_all_CMIP5, 1 )
    histo_all_CMIP6_clim  = dim_avg_n_Wrap(  histo_all_CMIP6, 1 )
    ;
    ; Diff to AWAP
    awap_clim_conf        = conform( histo_all_CMIP5_clim, awap_clim, (/1,2/) )
    histo_all_CMIP5_clim_bias  = histo_all_CMIP5_clim - awap_clim_conf
    copy_VarMeta( histo_all_CMIP5_clim, histo_all_CMIP5_clim_bias )
    delete([/ awap_clim_conf,  histo_all_CMIP5_clim/])
    awap_clim_conf        = conform( histo_all_CMIP6_clim, awap_clim, (/1,2/) )
    histo_all_CMIP6_clim_bias  = histo_all_CMIP6_clim - awap_clim_conf
    copy_VarMeta( histo_all_CMIP6_clim, histo_all_CMIP6_clim_bias )
    delete([/ awap_clim_conf, histo_all_CMIP6_clim /])
    ;
    ; MMM bias
    bias_CMIP5            = dim_avg_n_Wrap( histo_all_CMIP5_clim_bias, 0 )
    bias_CMIP6            = dim_avg_n_Wrap( histo_all_CMIP6_clim_bias, 0 )
    delete([/ histo_all_CMIP5_clim_bias, histo_all_CMIP6_clim_bias /])
    ;
    ;
    ;
    ;
    ; ---------------------------------------------------------------------------------------------------------
    ;                  plot
    ; ---------------------------------------------------------------------------------------------------------
    ;
    ;
    if any( index.eq.(/ "tnn", "txx", "wsdi"/) ) then
      res@cnFillPalette  = "amwg256" 
    else
      res@cnFillPalette  = "precip4_diff_19lev" 
    end if
    ;
    if index.eq."tnn" then
      lname_index        = "TNn"
      res@gsnSpreadColors = True
      res@gsnSpreadColorStart = 127
      res@gsnSpreadColorEnd   = 252
      res@cnLevelSelectionMode  = "ManualLevels"
      res@cnMinLevelValF =  1.
      res@cnMaxLevelValF =  9.
      res@cnLevelSpacingF=  1.0
    end if
    if index.eq."rx1day" then
      lname_index        = "Rx1day"
      delete([/ res@cnLevelSelectionMode, res@cnMinLevelValF, res@cnMaxLevelValF, res@cnLevelSpacingF /])
      delete([/ res@gsnSpreadColors, res@gsnSpreadColorStart, res@gsnSpreadColorEnd /])
      res@cnLevelSelectionMode  = "ManualLevels"
      res@cnMinLevelValF =  -50.
      res@cnMaxLevelValF =  50.
      res@cnLevelSpacingF=  10.0
    end if
    if index.eq."txx" then
      lname_index        = "TXx"
      delete([/ res@cnLevelSelectionMode, res@cnMinLevelValF, res@cnMaxLevelValF, res@cnLevelSpacingF /])
      res@cnLevelSelectionMode  = "ManualLevels"
      res@cnMinLevelValF =  -9.
      res@cnMaxLevelValF =  9.
      res@cnLevelSpacingF=  1.0
    end if
    if index.eq."r10mm" then
      lname_index        = "R10mm"
      delete([/ res@cnLevelSelectionMode, res@cnMinLevelValF, res@cnMaxLevelValF, res@cnLevelSpacingF /])
      res@cnLevelSelectionMode  = "ManualLevels"
      res@cnMinLevelValF =  -20.
      res@cnMaxLevelValF =  20.
      res@cnLevelSpacingF=  5.0
    end if
    if index.eq."wsdi" then
      lname_index        = "wsdi"
      delete([/ res@cnLevelSelectionMode, res@cnMinLevelValF, res@cnMaxLevelValF, res@cnLevelSpacingF /])
      res@gsnSpreadColors = True
      res@gsnSpreadColorStart = 127
      res@gsnSpreadColorEnd   = 252
    end if
    if index.eq."cdd" then
      lname_index        = "CDD"
      delete([/ res@gsnSpreadColors, res@gsnSpreadColorStart, res@gsnSpreadColorEnd /])
      res@gsnSpreadColors = True
      res@gsnSpreadColorStart = 19
      res@gsnSpreadColorEnd   = 0
      res@cnLevelSelectionMode  = "ManualLevels"
      res@cnMinLevelValF =  -30.
      res@cnMaxLevelValF =  30.
      res@cnLevelSpacingF=  10.0
    end if
    ;
    ;
    ;
    res@gsnLeftString  = " "+lname_index+" ("+units+")"
    delete( lname_index )
    ;
    ; LEFT: CMIP5
    res@lbLabelBarOn   = True	
    res@lbBoxLinesOn   = True
    res@tmXBLabelsOn   = False
    res@tmYLLabelsOn   = True
    res@tmYRLabelsOn   = False
    res@gsnRightString= "CMIP5"
    plots( id )         = gsn_csm_contour_map( wks, bias_CMIP5, res )
    ;
    ; RIGHT: CMIP6
    res@lbLabelBarOn   = False
    res@lbBoxLinesOn   = False
    res@tmXBLabelsOn   = True
    res@tmYLLabelsOn   = False
    res@tmYRLabelsOn   = True
    res@gsnLeftString  = " "
    res@gsnRightString= "CMIP6"
    plots_a( id )      = gsn_csm_contour_map( wks, bias_CMIP6, res )
    ;
    attach             = gsn_attach_plots( plots( id ), plots_a( id ), res, res )
    ;
    delete([/ bias_CMIP5, bias_CMIP6 /])
    ;
    delete( index )
  end do ; indices
  ;
  ;
  ; letters / panels
  txtres            = True
  txtres@txPerimThicknessF = 1
  txtres@txPerimColor    = 1
  txtres@txFontHeightF   = 0.025
  amres              = True
  amres@amParallelPosF   =  -0.45    ; This is the left edge of the plot.
  amres@amOrthogonalPosF =  -0.42
  dumtext_a          = gsn_create_text( wks, "a", txtres )
  dumtext_b          = gsn_create_text( wks, "b", txtres )
  dumtext_c          = gsn_create_text( wks, "c", txtres )
  dumtext_d          = gsn_create_text( wks, "d", txtres )
  dumtext_e          = gsn_create_text( wks, "e", txtres )
  dumtext_f          = gsn_create_text( wks, "f", txtres )
  annoid_a           = gsn_add_annotation( plots( 0  ), dumtext_a, amres )
  annoid_b           = gsn_add_annotation( plots( 1  ), dumtext_b, amres )
  annoid_c           = gsn_add_annotation( plots( 2  ), dumtext_c, amres )
  annoid_d           = gsn_add_annotation( plots( 3  ), dumtext_d, amres )
  annoid_e           = gsn_add_annotation( plots( 4  ), dumtext_e, amres )
  annoid_f           = gsn_add_annotation( plots( 5  ), dumtext_f, amres )
  ;
  ;
  pres               = True
  pres@gsnFrame      = False
  pres@txFontHeightF = 0.015
  gsn_panel( wks, plots, (/3,2/), pres )
  ;
  frame( wks )
  ;
  system( "display "+pathoutfig+namefig+"."+qual+" &" )
  ;
  ;
  ;
end
;EOF
