; Margot Bador, UNSW, m.bador@unsw.edu.au, 2020.
;
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"

begin
  ;
  ;
;########### Miscellaneous ##############################################"
  ; 
  index              = "r99ptot" ; rx1day r10mm cdd txx tnn wsdi
  ;
  ;
;#######################################################################"
  ;
  ; Prep loading the indice of every datasets
  pathin_root_CMIP5  = "/g/data/ua8/CanadaExtremeIndices/ftp.cccma.ec.gc.ca/data/climdex/CMIP5/"
  pathin_root_CMIP6  = "/g/data/w40/saw562/climpact/"
  pathout_root_CMIP5 = "/g/data/w40/mba561/cmip_regridded/CMIP5/"
  pathout_root_CMIP6 = "/g/data/w40/mba561/cmip_regridded/CMIP6/"
  ;                     
  ; ## Load model name list
  li_rcp85           = "list_models_rcp85_for_indices_CMIP5.txt"
  models_rcp85       = asciiread( li_rcp85,-1,"string" )
  nmodels_rcp85      = dimsizes( models_rcp85 )
  li_ssp585          = "list_models_ssp585_for_indices_CMIP6.txt"
  models_ssp585      = asciiread( li_ssp585,-1,"string" )
  nmodels_ssp585     = dimsizes( models_ssp585 )
  ;
  ; choice of interpolation
  temperature_indices  = (/ "dtr", "csdi", "wsdi", "fd", "gsl", "su", "tn10p", "tn90p", "tnn", \
                            "tnx", "tr", "tx10p", "tx90p", "txn", "txx" /)
  precipitation_indices= (/ "cdd", "cwd", "wsdi", "prcptot", "r10mm", "r20mm", "r99p", "r95p", \
                            "rx1day", "rx5day", "sdii" /)
  if any( temperature_indices.eq.index ) then
    interp           = "remapbil"
  end if
  if any( precipitation_indices.eq.index ) then
    interp           = "remapcon"
  end if
  ;
  ;
  ;
  ;
  ; ---------------------------------------------------------------------------------------------------------
  ;                  CMIP5 - rcp85
  ; ---------------------------------------------------------------------------------------------------------
  ;
  print(" --------------- ")
  print(" ---- CMIP5 ---- ")
  print(" --------------- ")
  print(" ")
  ;
  ; Loop through datasets  
  do m               = 0, nmodels_rcp85 - 1
    ;
    model            = models_rcp85( m )
    print( " "+model )
    ;
    ;
    ; ########################
    ; ### Historical
    ; ########################
    ;
    pathin           = pathin_root_CMIP5+"historical/"+model+"/"
    filein           = systemfunc( "ls "+pathin+"*/*/base_1961-1990/"+index+"ETCCDI_yr*" )
    ;
    if dimsizes( filein ).gt.1 then
      split1         = str_split_csv( filein,      model+"/", 0 )
      split2         = str_split_csv( split1(:,1), "/v",      0 )
      if model.eq."EC-EARTH" then
        i_r          = ind( split2( :,0 ).eq."r2i1p1" )
      else
        i_r          = ind( split2( :,0 ).eq."r1i1p1" )
      end if
      filein         := filein( i_r )
      delete([/ split1, split2, i_r /])
    end if
    ;
    split1           = str_split_csv( filein,      model+"/", 0 )
    split2           = str_split_csv( split1(0,1), "/v",      0 )
    member           = split2(0,0)
    split3           = str_split_csv( split2(0,1), member+"_",    0 )
    split4           = str_split_csv( split3(0,1), ".nc",         0 )
    dates            = split4(0,0)
    delete([/ split1, split2, split3, split4 /])
    ;
    print( " "+str_get_tab()+member )
    print( " "+str_get_tab()+"historical" )
    ;
    pathout          = pathout_root_CMIP5+"historical/"
    fileout          = index+"ETCCDI_yr_"+model+"_historical_"+member+"_"+dates+"_regridded.nc"
    command          := systemfunc( "cdo "+interp+",r240x120 "+filein+" "+pathout+fileout )
    ;
    delete([/ pathin, filein, pathout, fileout, dates /])
    ;
    ;
    ; ########################
    ; ### RCP8.5
    ; ########################
    ;
    pathin           = pathin_root_CMIP5+"rcp85/"+model+"/"
    filein           = systemfunc( "ls "+pathin+"*/*/*base*/"+index+"ETCCDI_yr*" )
    ;
    if dimsizes( filein ).gt.1 then
      split1         = str_split_csv( filein,      model+"/", 0 )
      split2         = str_split_csv( split1(:,1), "/v",      0 )
      i_r            = ind( split2( :,0 ).eq.member )
      filein         := filein( i_r )
      delete([/ split1, split2, i_r /])
    end if
    ;
    split1           = str_split_csv( filein,     "_rcp85_"+member+"_", 0 )
    split2           = str_split_csv( split1(0,1), ".nc",      0 )
    dates            = split2(0,0)
    delete([/ split1, split2 /])
    ;
    print( " "+str_get_tab()+"rcp85" )
    ;
    pathout          = pathout_root_CMIP5+"rcp85/"
    fileout          = index+"ETCCDI_yr_"+model+"_rcp85_"+member+"_"+dates+"_regridded.nc"
    command          := systemfunc( "cdo "+interp+",r240x120 "+filein+" "+pathout+fileout )
    ;
    delete([/ model, member /])
    delete([/ pathin, filein, pathout, fileout, dates /])
  end do ;  models rcp85
  ;
  ;
  ;
  ;
  ;
  ; ---------------------------------------------------------------------------------------------------------
  ;                  CMIP6 - ssp585
  ; ---------------------------------------------------------------------------------------------------------
  ;
  print(" ")
  print(" ")
  print(" ")
  print(" --------------- ")
  print(" ---- CMIP6 ---- ")
  print(" --------------- ")
  print(" ")
  ;
  ; Loop through datasets  
  do m               = 0, nmodels_ssp585 - 1
    ;
    model            = models_ssp585( m )
    print( " "+model )
    ;
    ;
    ; ########################
    ; ### Historical
    ; ########################
    ;
    pathin           = pathin_root_CMIP6+model+"_historical*"
    filein           = systemfunc( "ls "+pathin+"/"+index+"_ANN_*" )
    ;
    if dimsizes( filein ).gt.1 then
      split1         = str_split_csv( filein, "climpact."+model+"_historical_", 0 )
      split2         = str_split_csv( split1(:,1), "_",      0 )
      split3         = str_split_csv( split2(:,0), "f",      0 )
      split4         = str_split_csv( split2(:,1), ".nc",    0 )
      i_r            = ind( split3( :,0 ).eq."r1i1p1" )
      if dimsizes( i_r ).gt.1 then
        i_r          := i_r(  0 )
      end if
      filein         := filein( i_r )
      delete([/ split1, split2, split3, split4, i_r /])
    end if
    ;
    split1           = str_split_csv( filein, "climpact."+model+"_historical_", 0 )
    split2           = str_split_csv( split1(0,1), ".nc",      0 )
    member           = split2( 0,0 )
    delete([/ split1, split2 /])
    ;
    print( " "+str_get_tab()+member )
    print( " "+str_get_tab()+"historical" )
    ;
    pathout          = pathout_root_CMIP6+"historical/"
    fileout          = index+"_ANN_climpact."+model+"_historical_"+member+"_regridded.nc"
    command          := systemfunc( "cdo "+interp+",r240x120 "+filein+" "+pathout+fileout )
    ;
    delete([/ pathin, filein, pathout, fileout /])
    ;
    ;
    ; ########################
    ; ### SSP585
    ; ########################
    ;
    pathin           = pathin_root_CMIP6+model+"_ssp585_*"
    filein           = systemfunc( "ls "+pathin+"/"+index+"_ANN_*" )
    ;
    if dimsizes( filein ).gt.1 then
      split1       = str_split_csv( filein, "climpact."+model+"_ssp585_", 0 )
      split2       = str_split_csv( split1(:,1), ".nc",      0 )
      i_r          = ind( split2( :,0 ).eq.member )
      if dimsizes( i_r ).gt.1 then
        print("PB members ssp585")
        exit
      end if
      filein       := filein( i_r )
      delete([/ split1, split2, i_r /])
    end if
    ;
    print( " "+str_get_tab()+"ssp585" )
    ;
    pathout          = pathout_root_CMIP6+"ssp585/"
    fileout          = index+"_ANN_climpact."+model+"_ssp585_"+member+"_regridded.nc" 
    command          := systemfunc( "cdo "+interp+",r240x120 "+filein+" "+pathout+fileout )
    ;
    delete([/ model, member /])
    delete([/ pathin, filein, pathout, fileout /])
  end do ;  models ssp585
  ;
  ;
  ;
  ;
end
;EOF

