% Jules Kajtar, UTas, jules.kajtar@utas.edu.au
% JBK 05/11/19
% read daily CMIP5 or CMIP6 Aus region data
% compute ocean temperature extreme statistics
% on a grid-point basis

clear all;

modset='cmip6';  % cmip5 or cmip6

if strcmp(modset,'cmip5')
 scen='historical+rcp85';
else
 scen='historical';
end

% span of analysis
yrs=[1982 2014];
yrlab=[num2str(yrs(1)) '-' num2str(yrs(2))];

% set dates of climatological base-line period
clim_s=datetime(1996,1,1);
clim_e=datetime(2014,12,31);

% set paths
inpath=...;
outpath=...;

% load names of data files
% NOTE: raw data has been read from netcdf into matlab files
% + no regridding has been done yet, but data has been trimmed to
%   Australian region: 100-170E, 50-5S
% + for CMIP5 data, rcp85 has been appended to historical to give
%   required time-span
dirlist=dir([inpath '*.mat']);
mmax=length(dirlist);

for m=1:mmax
 
 % load data
 infile=[inpath dirlist(m).name];
 ds=load(infile);
 time_cal=ds.time_calendar;
  
 lon=double(ds.lon);
 lat=double(ds.lat);
 time=ds.time;
 time.Format='yyyy-MM-dd';  % change time format to be compatible
 
 % model label
 modcode=strrep(dirlist(m).name,'tos.day.','');
 modcode=strrep(modcode,['.' yrlab '.mat'],'');
 disp(modcode);
 
 % compute MHW statistics
 [MHW,mclim,m90,mhw_ts]=detect_mhw(ds.tos,time,clim_s,clim_e,time_cal);
 
 % count the total MHW days and find max intensity, per year, per grid-point
 kk=find(month(time)==1 & day(time)==1);  % find all Jan 1
 clear mhw_days mhw_max;
 for ii=1:numel(kk)
  jj=find(year(time)==year(time(kk(ii))));
  mhw_days(:,:,ii)=sum(~isnan(mhw_ts(:,:,jj)),3);
  mhw_max(:,:,ii)=max(mhw_ts(:,:,jj),[],3);
 end

 % store MHW signals
 outfile=[outpath 'mhw_stats.aus_region.' modcode '.' yrlab '.mat'];
 save(outfile,'lat','lon','mhw_days','mhw_max','time','time_cal','-v7.3');

 %end
end

