% Jules Kajtar, UTas, jules.kajtar@utas.edu.au
% JBK 25/09/19
% read daily noaa oi Aus region data
% compute ocean temperature extreme statistics
% on a grid-point basis

clear all;

% span of analysis
yrs=[1982 2014];
yrlab=[num2str(yrs(1)) '-' num2str(yrs(2))];

% set dates of climatological base-line period
clim_s=datetime(1996,1,1);
clim_e=datetime(2014,12,31);

% choose span of search for MHWs
time_span=[datetime(1982,1,1) datetime(2005,12,31)];

% set paths and input file
inpath=...;
outpath=...;
infile=...;

% load data
% NOTE: raw NOAA OI data has been read from netcdf into a matlab file
% no regridding has been done yet, but data has been trimmed to
% Australian region: 100-170E, 50-5S
ds=matfile([inpath infile]);
sst=ds.sst;
lon=double(ds.lon);
lat=double(ds.lat);
time=ds.time;
time.Format='yyyy-MM-dd';
clear ds;

[MHW,mclim,m90,mhw_ts]=detect_mhw(sst,time,clim_s,clim_e,'standard');

% count the total MHW days and find max intensity, per year, per grid-point
kk=find(month(time)==1 & day(time)==1);  % find all Jan 1
clear mhw_days mhw_max;
for ii=1:numel(kk)
 jj=find(year(time)==year(time(kk(ii))));
 mhw_days(:,:,ii)=sum(~isnan(mhw_ts(:,:,jj)),3);
 mhw_max(:,:,ii)=max(mhw_ts(:,:,jj),[],3);
end

% store MHW signals
outfile=[outpath 'mhw_stats.aus_region.noaa_oi.' yrlab '.mat'];
save(outfile,'lat','lon','mhw_days','mhw_max','time','clim_s','clim_e','-v7.3');

