% Jules Kajtar, UTas, jules.kajtar@utas.edu.au
% JBK 09/10/19 
% pre-process MHW statistics from CMIP5/CMIP6/OBS to common grid
% use observed grid as common grid
% interpolate using nearest neighbour, to preserve coarseness
% of CMIP statistics, without smoothing
% read model data, compute long-term means, re-grid

clear all;

modset='cmip6';  % run for both CMIP5 and CMIP6

if strcmp(modset,'cmip5')
 scen='historical+rcp85';
else
 scen='historical';
end

% span of analysis
yrs=[1982 2014];
yrlab=[num2str(yrs(1)) '-' num2str(yrs(2))];
ny=yrs(2)-yrs(1)+1;

% region bounds
reg_bounds=[100 170 -50 -5];

% set paths
sourcepath=...;
inpath=...;
outpath=...;

% read CMIP models in path
dirlist=dir([inpath '*.mat']);
mmax=length(dirlist)+1;  % +1 for observations

% store full paths to data, but use observations as first set
infiles{1}=[sourcepath 'mhw_stats.aus_region.noaa_oi.' yrlab '.mat'];
infiles(2:mmax)=strcat(inpath,{dirlist.name});

for m=1:mmax

 % model label
 if m==1
  modname='noaa_oi';
 else
  modname=strrep(dirlist(m-1).name,'mhw_stats.aus_region.','');
  modname=strrep(modname,['.' yrlab '.mat'],'');
  modname=strrep(modname,['.' scen],'');
  modname=regexprep(modname,'.r\w*i\w*p\w*','');
 end
 disp(modname);
 modcode{m}=modname;
  
 % load data
 ds=load(infiles{m});
 
 % set land values in mhw_days to nan, instead of zero
 % by finding points where all mhw_max values are nan
 land_mask=all(isnan(ds.mhw_max),3);
 land_mask=repmat(land_mask,[1 1 ny]);
 ds.mhw_days(find(land_mask))=nan;
 clear land_mask;
 
 % rotate coordinates, if required
 if min(min(ds.lon))<0
  ds.lon=ds.lon+360;
 end
 
 % store observations in first position of global array
 if m==1
  lat=ds.lat;
  lon=ds.lon;
  [yq,xq]=meshgrid(lat,lon);
  mm=ds.mhw_max;
  md=ds.mhw_days;
 else
  % use meshgrid to create 2D arrays if lon/lat is 1D
  if any(size(ds.lon)==1)
   [ds.lat,ds.lon]=meshgrid(ds.lat,ds.lon);
  end
  
  % regrid models onto observed grid
  for kk=1:ny
   mm(:,:,kk,m)=griddata(ds.lon,ds.lat,ds.mhw_max(:,:,kk),xq,yq,'nearest');
   md(:,:,kk,m)=griddata(ds.lon,ds.lat,ds.mhw_days(:,:,kk),xq,yq,'nearest');
  end
 end
end

% compute max intensity and mean MHW days over whole period
%mhw_max=max(mm,[],4);   % maximum intensity
mhw_max=squeeze(nanmean(mm,3));   % long-term mean of annual maximum
mhw_days=squeeze(mean(md,3));

% compute annual area averages for time-series plots
AREA=area_make(lon,lat);
S=size(mm);
AREA=repmat(AREA,[1 1 S(3)]);

for m=1:mmax
 mhw_max_ts(:,m)=area_average(mm(:,:,:,m),AREA,1);
 mhw_days_ts(:,m)=area_average(md(:,:,:,m),AREA,1);
end

% save data
outfile=[outpath 'mhw_stats.aus_region.' modset '.' yrlab '.mat'];
save(outfile,'lat','lon','modcode','mhw_max','mhw_days','mhw_max_ts','mhw_days_ts','-v7.3');



