% % % plot mean sea level and dynamic sea level projections for Figure 7 of
% % % Grose et al. (2020) Earth's Future
% % % Contact: Kewei Lyu, CSIRO (kewei.marine@gmail.com)
% % % Need subroutine tight_subplot and m_map toolbox

close all;clear;clc;font_size=16;
cn=20; my_color=colormap(jet(cn+4));my_color(cn/2+1:cn/2+4,:)=[];close;

% % % Begin read data
filename='plot_dsl_mean_proj_for_AUS_paper.nc';
vls.nam = {'lat','lon','obs_dsl_mean','cmip5_dsl_mean','cmip6_dsl_mean',...
    'lon_proj','lat_proj','cmip5_dsl_proj','cmip6_dsl_proj',...
    'lon_ofam3','lat_ofam3','ofam3_dsl_proj'};
vls.num = length(vls.nam);
for i1 = 1:vls.num
  vna = vls.nam{i1};
  tmp=squeeze(ncread(filename,vna));
  eval([vna ' = tmp;']); clear tmp i1
end
[lat,lon]=meshgrid(lat,lon);
[lat_proj,lon_proj]=meshgrid(lat_proj,lon_proj);
[lat_ofam3,lon_ofam3]=meshgrid(lat_ofam3,lon_ofam3);
% % % End read data

% % % Begin plotting mean sea level
figure('color','w','position',[0 0 600 600*26/20]);
ha = tight_subplot(3,1,[-0.08 0.01],[.06 .06],[.09 .14]);  
% gaps in height and width  lower upper left right
name={'(a) Mean sea level: Observation','(b) Mean sea level: CMIP5 - Observation','(c) Mean sea level: CMIP6 - Observation',...
    '(d) CMIP5 Projection','(e) CMIP6 Projection','(f) CMIP5 Projection (downscaled)'};
for panel=[1 2 3]
axes(ha(panel));m_proj('Equidistant cylindrical','lon',[45 290],'lat',[-50 15]);
hold on;m_grid('box','on','linestyle','none','tickdir','out',...
    'xtick',60:30:270,'ytick',-45:15:15,'ticklen',0.018,'fontsize',font_size,'fontname','times'); 
hold on;m_coast('patch',[.7 .7 .7],'edgecolor','none');set(gca,'fontname','times','fontsize',font_size)
if panel==1
hold on;m_contourf(lon,lat,obs_dsl_mean,-300:5:300,'linestyle','none');caxis([-100 100]);
hc1=colorbar('location','eastoutside','fontname','times','fontsize',font_size);
set(hc1,'position',[0.9 0.685 0.012 0.165])
elseif panel==2
hold on;m_contourf(lon,lat,cmip5_dsl_mean-obs_dsl_mean,-300:2:300,'linestyle','none');caxis([-40 40]);  
hc2=colorbar('location','eastoutside','fontname','times','fontsize',font_size);
set(hc2,'position',[0.9 0.417 0.012 0.165])
else
hold on;m_contourf(lon,lat,cmip6_dsl_mean-obs_dsl_mean,-300:2:300,'linestyle','none');caxis([-40 40]);
hc3=colorbar('location','eastoutside','fontname','times','fontsize',font_size);
set(hc3,'position',[0.9 0.152 0.012 0.165])
end
colormap(my_color);
hold on;t=title(name{panel},'fontname','times','fontsize',font_size,'fontweight','normal');
h1 = get(t, 'position');set(t, 'position', [0 h1(2)+0.05 h1(3)]);
end
figname='plot_dsl_mean_for_AUS_paper';
set(gcf,'PaperType','A4',...
'PaperOrientation','portrait',...  %landscape
'PaperUnits','Centimeters',...
'PaperPosition',[0.5 2 20 26]);
% print(gcf,'-dtiff','-r600',figname);
% % % End plotting mean sea level

% % % Begin plotting dynamic sea level projections
figure('color','w','position',[0 0 600 600*26/20]);
ha = tight_subplot(3,1,[0.085 0.01],[.13 .13],[.05 .05]);  
% gaps in height and width  lower upper left right
name={'(d) CMIP5 Projection','(e) CMIP6 Projection','(f) CMIP5 Projection (downscaled)'};
for panel=[1 2 3]
axes(ha(panel));m_proj('Equidistant cylindrical','lon',[105 165],'lat',[-50 0]);
hold on;m_grid('box','on','linestyle','none','tickdir','out',...
    'xtick',105:20:165,'ytick',-45:15:15,'ticklen',0.018,'fontsize',font_size,'fontname','times'); 
hold on;m_coast('patch',[.7 .7 .7],'edgecolor','none');set(gca,'fontname','times','fontsize',font_size)
if panel==1
hold on;m_contourf(lon_proj,lat_proj,cmip5_dsl_proj,-20:1:20,'linestyle','none');
hc1=colorbar('location','eastoutside','fontname','times','fontsize',font_size);
set(hc1,'position',[0.68 0.68 0.012 0.165])
elseif panel==2
hold on;m_contourf(lon_proj,lat_proj,cmip6_dsl_proj,-20:1:20,'linestyle','none');
hc2=colorbar('location','eastoutside','fontname','times','fontsize',font_size);
set(hc2,'position',[0.68 0.413 0.012 0.165])
else
hold on;m_contourf(lon_ofam3,lat_ofam3,ofam3_dsl_proj,-20:1:20,'linestyle','none');
hc3=colorbar('location','eastoutside','fontname','times','fontsize',font_size);
set(hc3,'position',[0.68 0.144 0.012 0.165])
end
colormap(my_color);caxis([-20 20])
hold on;t=title(name{panel},'fontname','times','fontsize',font_size,'fontweight','normal');
h1 = get(t, 'position');set(t, 'position', [0 h1(2)+0.02 h1(3)]);
end
figname='plot_dsl_proj_for_AUS_paper';
set(gcf,'PaperType','A4',...
'PaperOrientation','portrait',...  %landscape
'PaperUnits','Centimeters',...
'PaperPosition',[0.5 2 20 26]);
% print(gcf,'-dtiff','-r600',figname);
% % % End plotting dynamic sea level projections
